@@ -2,9 +2,8 @@
  * @file arpwidget_lv2.cpp
  * @brief Implements the the LV2 GUI for the QMidiArp Arp plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -31,7 +30,7 @@ ArpWidgetLV2::ArpWidgetLV2 (
         LV2UI_Controller ct,
         LV2UI_Write_Function write_function,
         const LV2_Feature *const *host_features)
-        : ArpWidget(true, true, true, 0)
+        : ArpWidget(true, true, true)
 {
     m_controller = ct;
     writeFunction = write_function;
@@ -74,9 +73,9 @@ ArpWidgetLV2::ArpWidgetLV2 (
     connect(transportBox, SIGNAL(toggled(bool)), tempoSpin, SLOT(setDisabled(bool)));
     transportBox->setChecked(true);
 
-    inOutBox->layout()->addWidget(transportBoxLabel);
-    inOutBox->layout()->addWidget(transportBox);
-    inOutBox->layout()->addWidget(tempoSpin);
+    inOutBoxWidget->layout()->addWidget(transportBoxLabel);
+    inOutBoxWidget->layout()->addWidget(transportBox);
+    inOutBoxWidget->layout()->addWidget(tempoSpin);
 
     connect(attackTime,         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(releaseTime,        SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
@@ -93,11 +92,13 @@ ArpWidgetLV2::ArpWidgetLV2 (
     connect(patternPresetBox,   SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(repeatPatternThroughChord, SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(octaveModeBox,      SIGNAL(activated(int)), this, SLOT(mapParam(int)));
-    connect(octaveRangeBox,      SIGNAL(activated(int)), this, SLOT(mapParam(int)));
+    connect(octaveLowBox,       SIGNAL(activated(int)), this, SLOT(mapParam(int)));
+    connect(octaveHighBox,      SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(patternText,        SIGNAL(textChanged(const QString&)), this,
             SLOT(updatePattern(const QString&)));
 
     connect(muteOutAction,      SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
+    connect(latchModeAction,    SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
     connect(deferChangesAction, SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
     connect(enableRestartByKbd, SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
     connect(enableTrigByKbd,    SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
@@ -130,7 +131,7 @@ void ArpWidgetLV2::port_event ( uint32_t port_index,
     if (!receivedPatternOnce) sendUIisUp(true);
 
     if (format == uris->atom_eventTransfer
-      && atom->type == uris->atom_Blank) {
+      && atom->type == uris->atom_Object) {
         receivePattern(atom);
     }
     else if (format == 0 && buffer_size == sizeof(float)) {
@@ -179,10 +180,11 @@ void ArpWidgetLV2::port_event ( uint32_t port_index,
             case OCTAVE_MODE:
                     octaveModeBox->setCurrentIndex(fValue);
             break;
-            case OCTAVE_RANGE:
-                    octaveRangeBox->setCurrentIndex((int)fValue - 1);
+            case OCTAVE_LOW:
+                    octaveLowBox->setCurrentIndex(-(int)fValue);
             break;
-            case MOUSEPRESSED:
+            case OCTAVE_HIGH:
+                    octaveHighBox->setCurrentIndex((int)fValue);
             break;
             case INDEX_IN1:
                     indexIn[0]->setValue(fValue);
@@ -343,7 +345,7 @@ void ArpWidgetLV2::sendPattern(const QString & p)
 
     /* prepare forge buffer and initialize atom-sequence */
     lv2_atom_forge_set_buffer(&forge, obj_buf, 256);
-    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_blank(&forge, &frame, 1, uris->pattern_string);
+    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_object(&forge, &frame, 1, uris->pattern_string);
 
     /* forge container object of type 'pattern_string' */
     lv2_atom_forge_property_head(&forge, uris->pattern_string, 0);
@@ -368,7 +370,7 @@ void ArpWidgetLV2::sendUIisUp(bool on)
 
     if (on) state = uris->ui_up; else state=uris->ui_down;
 
-    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_blank(&forge, &frame, 1, state);
+    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_object(&forge, &frame, 1, state);
 
     /* close-off frame */
     lv2_atom_forge_pop(&forge, &frame);
@@ -378,7 +380,8 @@ void ArpWidgetLV2::sendUIisUp(bool on)
 void ArpWidgetLV2::receivePattern(LV2_Atom* atom)
 {
     QMidiArpURIs* const uris = &m_uris;
-    if (atom->type != uris->atom_Blank) return;
+    if ( (atom->type != uris->atom_Blank) 
+            && (atom->type != uris->atom_Object)) return;
 
     receivedPatternOnce = true;
 
@@ -404,7 +407,10 @@ void ArpWidgetLV2::receivePattern(LV2_Atom* atom)
 void ArpWidgetLV2::mapBool(bool on)
 {
     float value = (float)on;
-    if (muteOutAction == sender())              updateParam(MUTE, value);
+    if (muteOutAction == sender()) {
+        updateParam(MUTE, value);
+        screen->setMuted(value);
+    }
     else if (deferChangesAction == sender())    updateParam(DEFER, value);
     else if (latchModeAction == sender())       updateParam(LATCH_MODE, value);
     else if (transportBox == sender())          updateParam(TRANSPORT_MODE, value);
@@ -429,7 +435,8 @@ void ArpWidgetLV2::mapParam(int value)
     else if (rangeIn[1] == sender())        updateParam(RANGE_IN2, value);
     else if (repeatPatternThroughChord == sender()) updateParam(REPEAT_MODE, value);
     else if (octaveModeBox == sender())     updateParam(OCTAVE_MODE, value);
-    else if (octaveRangeBox == sender())    updateParam(OCTAVE_RANGE, value + 1);
+    else if (octaveLowBox == sender())      updateParam(OCTAVE_LOW, -value);
+    else if (octaveHighBox == sender())     updateParam(OCTAVE_HIGH, value);
     else if (tempoSpin == sender())         updateParam(TEMPO, value);
 }
 
