@@ -2,9 +2,8 @@
  * @file arpwidget_lv2.cpp
  * @brief Headers for the LV2 GUI for the QMidiArp Arp plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -56,8 +55,8 @@ class ArpWidgetLV2 : public ArpWidget
             MUTE = 12,
             LATCH_MODE = 13,
             OCTAVE_MODE = 14,
-            OCTAVE_RANGE = 15,
-            MOUSEPRESSED = 16,
+            OCTAVE_LOW = 15,
+            OCTAVE_HIGH = 16,
             INDEX_IN1 = 17,
             INDEX_IN2 = 18,
             RANGE_IN1 = 19,
