@@ -2,9 +2,8 @@
  * @file engine.cpp
  * @brief Implementation of the Engine class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -31,7 +30,9 @@
 #include "engine.h"
 
 
-Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portCount, bool p_alsamidi, QWidget *parent) : QObject(parent), modified(false)
+Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, 
+            int p_portCount, bool p_alsamidi, QWidget *parent) 
+            : QObject(parent), modified(false)
 {
     ready = false;
 
@@ -39,15 +40,15 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portC
     logTickBuffer.resize(128);
     logEventCount = 0;
 
-    midiControl = new MidiControl();
+    midiControl = new MidiControl;
     midiControl->ID = -3;
     midiControl->parentDockID = -3;
-    connect(midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            this, SLOT(setMidiLearn(int, int, int)));
+    connect(midiControl, SIGNAL(setMidiLearn(int, int)),
+            this, SLOT(setMidiLearn(int, int)));
 
     globStoreWidget = p_globStore;
-    connect(globStoreWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            this, SLOT(setMidiLearn(int, int, int)));
+    connect(globStoreWidget->midiControl, SIGNAL(setMidiLearn(int, int)),
+            this, SLOT(setMidiLearn(int, int)));
 
     grooveWidget = p_grooveWidget;
     connect(grooveWidget, SIGNAL(newGrooveTick(int)),
@@ -56,18 +57,22 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portC
             this, SLOT(setGrooveVelocity(int)));
     connect(grooveWidget, SIGNAL(newGrooveLength(int)),
             this, SLOT(setGrooveLength(int)));
-    connect(grooveWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            this, SLOT(setMidiLearn(int, int, int)));
+    connect(grooveWidget->midiControl, SIGNAL(setMidiLearn(int, int)),
+            this, SLOT(setMidiLearn(int, int)));
     portCount = p_portCount;
 
     if (!p_alsamidi) {
-        driver = new JackDriver(portCount, this, tr_state_cb, midi_event_received_callback, tick_callback, tempo_callback);
+        driver = new JackDriver(portCount, this, tr_state_cb, 
+                midi_event_received_callback, tick_callback, tempo_callback);
     }
     else {
-    // In case of ALSA MIDI with Jack Transport sync, JackDriver is instantiated with 0 ports
+    // In case of ALSA MIDI with Jack Transport sync, JackDriver is 
+    // instantiated with 0 ports
     // a pointer to jackSync has to be passed to driver
-        jackSync = new JackDriver(0, this, tr_state_cb, midi_event_received_callback, tick_callback, tempo_callback);
-        driver = new SeqDriver(jackSync, portCount, this, midi_event_received_callback, tick_callback);
+        jackSync = new JackDriver(0, this, tr_state_cb, 
+                midi_event_received_callback, tick_callback, tempo_callback);
+        driver = new SeqDriver(jackSync, portCount, this, 
+                midi_event_received_callback, tick_callback);
     }
 
     midiLearnFlag = false;
@@ -103,6 +108,7 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portC
 Engine::~Engine()
 {
     delete driver;
+    delete midiControl;
 }
 
 //Arp handling
@@ -136,8 +142,7 @@ void Engine::removeArpWidget(ArpWidget *arpWidget)
 
 void Engine::updatePatternPresets(const QString& n, const QString& p, int index)
 {
-    int l1;
-    for (l1 = 0; l1 < midiArpCount(); l1++) {
+    for (int l1 = 0; l1 < midiArpCount(); l1++) {
         arpWidgetList.at(l1)->updatePatternPresets(n, p, index);
     }
 }
@@ -186,25 +191,9 @@ void Engine::setGrooveLength(int val)
 
 void Engine::sendGroove()
 {
-    int l1;
-
-    for (l1 = 0; l1 < midiArpList.count(); l1++) {
-        midiArp(l1)->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
-        arpWidget(l1)->screen->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
-    }
-    for (l1 = 0; l1 < midiSeqList.count(); l1++) {
-        midiSeq(l1)->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
-        seqWidget(l1)->screen->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
-    }
-    for (l1 = 0; l1 < midiLfoList.count(); l1++) {
-        midiLfo(l1)->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
-        lfoWidget(l1)->screen->newGrooveValues(grooveTick, grooveVelocity,
-                grooveLength);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())
+            ->newGrooveValues(grooveTick, grooveVelocity, grooveLength);
     }
 }
 
@@ -333,12 +322,11 @@ int Engine::moduleWindowCount()
     return(moduleWindowList.count());
 }
 
-void Engine::renameDock(const QString& name, int parentDockID, int widgetID)
+void Engine::renameDock(const QString& name, int parentDockID)
 {
     moduleWindow(parentDockID)->setWindowTitle(name);
-    if (name.startsWith('S')) seqWidget(widgetID)->parStore->topButton->setText(name);
-    if (name.startsWith('L')) lfoWidget(widgetID)->parStore->topButton->setText(name);
-    if (name.startsWith('A')) arpWidget(widgetID)->parStore->topButton->setText(name);
+    ((InOutBox *)moduleWindow(parentDockID)->widget())
+            ->parStore->topButton->setText(name);
     setModified(true);
 }
 
@@ -347,32 +335,29 @@ void Engine::updateIDs(int curID)
 {
     int l1, tempDockID;
     for (l1 = 0; l1 < arpWidgetCount(); l1++) {
-        arpWidget(l1)->manageBox->ID = l1;
+        arpWidget(l1)->ID = l1;
         arpWidget(l1)->midiControl->ID = l1;
-        arpWidget(l1)->setProperty("widgetID", l1);
-        tempDockID = arpWidget(l1)->manageBox->parentDockID;
+        tempDockID = arpWidget(l1)->parentDockID;
         if (tempDockID > curID) {
-            arpWidget(l1)->manageBox->parentDockID = tempDockID - 1;
+            arpWidget(l1)->parentDockID = tempDockID - 1;
             arpWidget(l1)->midiControl->parentDockID = tempDockID - 1;
         }
     }
     for (l1 = 0; l1 < lfoWidgetCount(); l1++) {
-        lfoWidget(l1)->manageBox->ID = l1;
+        lfoWidget(l1)->ID = l1;
         lfoWidget(l1)->midiControl->ID = l1;
-        lfoWidget(l1)->setProperty("widgetID", l1);
-        tempDockID = lfoWidget(l1)->manageBox->parentDockID;
+        tempDockID = lfoWidget(l1)->parentDockID;
         if (tempDockID > curID) {
-            lfoWidget(l1)->manageBox->parentDockID = tempDockID - 1;
+            lfoWidget(l1)->parentDockID = tempDockID - 1;
             lfoWidget(l1)->midiControl->parentDockID = tempDockID - 1;
         }
     }
     for (l1 = 0; l1 < seqWidgetCount(); l1++) {
-        seqWidget(l1)->manageBox->ID = l1;
+        seqWidget(l1)->ID = l1;
         seqWidget(l1)->midiControl->ID = l1;
-        seqWidget(l1)->setProperty("widgetID", l1);
-        tempDockID = seqWidget(l1)->manageBox->parentDockID;
+        tempDockID = seqWidget(l1)->parentDockID;
         if (tempDockID > curID) {
-            seqWidget(l1)->manageBox->parentDockID = tempDockID - 1;
+            seqWidget(l1)->parentDockID = tempDockID - 1;
             seqWidget(l1)->midiControl->parentDockID = tempDockID - 1;
         }
     }
@@ -397,43 +382,25 @@ bool Engine::isModified()
 {
     if (!moduleWindowCount()) return false;
 
-    bool arpmodified = false;
-    bool lfomodified = false;
-    bool seqmodified = false;
+    bool modmodified = false;
 
-    for (int l1 = 0; l1 < arpWidgetCount(); l1++)
-        if (arpWidget(l1)->isModified()) {
-            arpmodified = true;
-            break;
-        }
-    for (int l1 = 0; l1 < lfoWidgetCount(); l1++)
-        if (lfoWidget(l1)->isModified()) {
-            lfomodified = true;
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        if ( ((InOutBox *)moduleWindow(l1)->widget())->isModified() ) {
+            modmodified = true;
             break;
         }
+    }
 
-    for (int l1 = 0; l1 < seqWidgetCount(); l1++)
-        if (seqWidget(l1)->isModified()) {
-            seqmodified = true;
-            break;
-        }
-
-    return (modified || arpmodified || lfomodified || seqmodified
-            || globStoreWidget->isModified());
+    return (modified || modmodified || globStoreWidget->isModified());
 }
 
 void Engine::setModified(bool m)
 {
     modified = m;
 
-    for (int l1 = 0; l1 < arpWidgetCount(); l1++)
-        arpWidget(l1)->setModified(m);
-
-    for (int l1 = 0; l1 < lfoWidgetCount(); l1++)
-        lfoWidget(l1)->setModified(m);
-
-    for (int l1 = 0; l1 < seqWidgetCount(); l1++)
-        seqWidget(l1)->setModified(m);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->setModified(m);
+    }
 
     globStoreWidget->setModified(m);
 }
@@ -604,16 +571,16 @@ void Engine::echoCallback(bool echo_from_trig)
                             l2++;
                         }
                     }
-                    frameptr = midiArp(l1)->getGrooveIndex() - 1;
+                    frameptr = midiArp(l1)->getGrooveIndex();
                     if (midiArp(l1)->nPoints)
-                        percent = frameptr * 100 / (midiArp(l1)->nPoints);
+                        percent = (frameptr - 1) * 100 / (midiArp(l1)->nPoints);
                     else
                         percent = 0;
                     arpWidget(l1)->parStore->ndc->updatePercent(percent);
                     if ((restoreModType == 'A') && (l1 == restoreModIx)
                             && (!globStoreWidget->timeModeBox->currentIndex())) {
                         globStoreWidget->indicator->updatePercent(percent);
-                        if (!frameptr && restoreFlag) {
+                        if ((!frameptr || (frameptr == midiArp(l1)->nPoints)) && restoreFlag) {
                             restoreTick = note_tick;
                             restoreFlag = false;
                         }
@@ -683,7 +650,19 @@ bool Engine::eventCallback(MidiEvent inEv)
             return(false);
         }
     }
-
+    if (midiLearnFlag && inEv.type == EV_NOTEON) {   //input range midi learn
+        if (midiLearnWindowID > 0) {
+            if (midiLearnID == 10) {
+                ((InOutBox *)moduleWindow(midiLearnModuleID)->widget())
+                    ->indexIn[0]->setValue(inEv.data);
+            }
+            else if (midiLearnID == 11) {
+                ((InOutBox *)moduleWindow(midiLearnModuleID)->widget())
+                    ->indexIn[1]->setValue(inEv.data);
+            }
+            midiLearnFlag = false;
+        }
+    }
     for (l1 = 0; l1 < midiLfoCount(); l1++) {
         unmatched = midiLfo(l1)->handleEvent(inEv, tick);
         if (midiLfo(l1)->gotKbdTrig) {
@@ -724,30 +703,21 @@ bool Engine::eventCallback(MidiEvent inEv)
 
 void Engine::showAllIOPanels(bool on)
 {
-    int l1;
-
-    for (l1 = 0; l1 < arpWidgetCount(); l1++)
-        arpWidget(l1)->hideInOutBoxAction->setChecked(on);
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++)
-        lfoWidget(l1)->hideInOutBoxAction->setChecked(on);
-    for (l1 = 0; l1 < seqWidgetCount(); l1++)
-        seqWidget(l1)->hideInOutBoxAction->setChecked(on);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->hideInOutBoxAction->setChecked(on);
+    }
 }
 
 void Engine::sendController(int ccnumber, int channel, int value)
 {
-    int l1;
-
     handleController(ccnumber, channel, value);
     grooveWidget->handleController(ccnumber, channel, value);
     globStoreWidget->handleController(ccnumber, channel, value);
 
-    for (l1 = 0; l1 < arpWidgetCount(); l1++)
-        arpWidget(l1)->handleController(ccnumber, channel, value);
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++)
-        lfoWidget(l1)->handleController(ccnumber, channel, value);
-    for (l1 = 0; l1 < seqWidgetCount(); l1++)
-        seqWidget(l1)->handleController(ccnumber, channel, value);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())
+            ->handleController(ccnumber, channel, value);
+    }
 }
 
 void Engine::learnController(int ccnumber, int channel)
@@ -775,19 +745,11 @@ void Engine::learnController(int ccnumber, int channel)
 
     int min = (midiLearnID) ? 0 : 127; //if control is toggle min=max
 
-    if (midiLearnWindowID == 1) {
-        arpWidget(midiLearnModuleID)->midiControl->requestAppendMidiCC(midiLearnID,
+    if (midiLearnWindowID > 0) {
+        ((InOutBox *)moduleWindow(midiLearnModuleID)->widget())
+                ->midiControl->requestAppendMidiCC(midiLearnID,
                 ccnumber, channel, min, 127);
     }
-    if (midiLearnWindowID == 2) {
-        lfoWidget(midiLearnModuleID)->midiControl->requestAppendMidiCC(midiLearnID,
-                ccnumber, channel, min, 127);
-    }
-    if (midiLearnWindowID == 3) {
-        seqWidget(midiLearnModuleID)->midiControl->requestAppendMidiCC(midiLearnID,
-                ccnumber, channel, min, 127);
-    }
-
     midiLearnFlag = false;
 }
 
@@ -853,7 +815,7 @@ void Engine::setUseJackTransport(bool on)
     modified = true;
 }
 
-void Engine::setMidiLearn(int moduleWindowID, int moduleID, int controlID)
+void Engine::setMidiLearn(int moduleWindowID, int controlID)
 {
     if (0 > controlID) {
         midiLearnFlag = false;
@@ -862,13 +824,8 @@ void Engine::setMidiLearn(int moduleWindowID, int moduleID, int controlID)
     else {
         midiLearnFlag = true;
         midiLearnWindowID = moduleWindowID;
-        if (midiLearnWindowID >= 0) {
-            QChar test = moduleWindow(midiLearnWindowID)->objectName().at(0);
-            if (test == 'A') midiLearnWindowID = 1;
-            if (test == 'L') midiLearnWindowID = 2;
-            if (test == 'S') midiLearnWindowID = 3;
-        }
-        midiLearnModuleID = moduleID;
+        if (midiLearnWindowID >= 0) midiLearnWindowID = 1;
+        midiLearnModuleID = moduleWindowID;
         midiLearnID = controlID;
     }
 }
@@ -904,16 +861,8 @@ void Engine::tr_state_cb(bool on, void *context)
 
 void Engine::store(int ix)
 {
-    int l1;
-
-    for (l1 = 0; l1 < arpWidgetCount(); l1++) {
-        arpWidget(l1)->storeParams(ix);
-    }
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++) {
-        lfoWidget(l1)->storeParams(ix);
-    }
-    for (l1 = 0; l1 < seqWidgetCount(); l1++) {
-        seqWidget(l1)->storeParams(ix);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->storeParams(ix);
     }
 }
 
@@ -941,19 +890,11 @@ void Engine::schedRestore(int ix)
 
 void Engine::restore(int ix)
 {
-    int l1;
-    for (l1 = 0; l1 < arpWidgetCount(); l1++) {
-        arpWidget(l1)->restoreParams(ix);
-        arpWidget(l1)->parStore->oldRestoreRequest = ix;
-    }
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++) {
-        lfoWidget(l1)->restoreParams(ix);
-        lfoWidget(l1)->parStore->oldRestoreRequest = ix;
-    }
-    for (l1 = 0; l1 < seqWidgetCount(); l1++) {
-        seqWidget(l1)->restoreParams(ix);
-        seqWidget(l1)->parStore->oldRestoreRequest = ix;
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->restoreParams(ix);
+        ((InOutBox *)moduleWindow(l1)->widget())->parStore->oldRestoreRequest = ix;
     }
+
     restoreRequest = -1;
 
     globStoreWidget->requestDispState(ix, 1);
@@ -961,15 +902,8 @@ void Engine::restore(int ix)
 
 void Engine::removeParStores(int ix)
 {
-    int l1;
-    for (l1 = 0; l1 < arpWidgetCount(); l1++) {
-        arpWidget(l1)->parStore->removeLocation(ix);
-    }
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++) {
-        lfoWidget(l1)->parStore->removeLocation(ix);
-    }
-    for (l1 = 0; l1 < seqWidgetCount(); l1++) {
-        seqWidget(l1)->parStore->removeLocation(ix);
+    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->parStore->removeLocation(ix);
     }
 }
 
@@ -978,8 +912,7 @@ void Engine::updateGlobRestoreTimeModule(int windowIndex)
     restoreModType = globStoreWidget->timeModuleBox
                         ->itemText(windowIndex).at(0);
 
-    restoreModIx = moduleWindowList.at(windowIndex)->widget()
-                        ->property("widgetID").toInt();
+    restoreModIx = ((InOutBox *)moduleWindow(windowIndex)->widget())->ID;
 }
 
 void Engine::updateDisplay()
@@ -995,14 +928,8 @@ void Engine::updateDisplay()
         schedRestoreLocation = -1;
     }
 
-    for (l1 = 0; l1 < arpWidgetCount(); l1++) {
-        arpWidget(l1)->updateDisplay();
-    }
-    for (l1 = 0; l1 < lfoWidgetCount(); l1++) {
-        lfoWidget(l1)->updateDisplay();
-    }
-    for (l1 = 0; l1 < seqWidgetCount(); l1++) {
-        seqWidget(l1)->updateDisplay();
+    for (l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->updateDisplay();
     }
 
     globStoreWidget->updateDisplay();
