@@ -2,9 +2,8 @@
  * @file groovewidget.cpp
  * @brief Implementation of the GrooveWidget QWidget class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -36,7 +35,7 @@
 #include "slider.h"
 
 
-GrooveWidget::GrooveWidget(QWidget *parent) : QWidget(parent)
+GrooveWidget::GrooveWidget()
 {
     midiControl = new MidiControl(this);
     midiControl->ID = -1;
@@ -73,10 +72,6 @@ GrooveWidget::GrooveWidget(QWidget *parent) : QWidget(parent)
     needsGUIUpdate = false;
 }
 
-GrooveWidget::~GrooveWidget()
-{
-}
-
 void GrooveWidget::updateGrooveVelocity(int val)
 {
     emit(newGrooveVelocity(val));
