@@ -2,9 +2,8 @@
  * @file indicator.cpp
  * @brief Implementation of the Indicator class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -31,7 +30,7 @@
 #include "indicator.h"
 
 
-Indicator::Indicator(int size, QChar modType, QWidget* parent) : QWidget (parent)
+Indicator::Indicator(int size, QChar modType)
 {
     p_angle = 0;
     p_size = size;
@@ -54,10 +53,6 @@ Indicator::Indicator(int size, QChar modType, QWidget* parent) : QWidget (parent
     isMuted = false;
 }
 
-Indicator::~Indicator()
-{
-}
-
 // Paint event handler.
 void Indicator::paintEvent(QPaintEvent*)
 {
