@@ -2,9 +2,8 @@
  * @file indicator.h
  * @brief Header for the Indicator class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -47,8 +46,7 @@ class Indicator : public QWidget
     virtual void paintEvent(QPaintEvent *);
 
   public:
-    Indicator(int size, QChar modType = ' ', QWidget* parent=0);
-    ~Indicator();
+    Indicator(int size, QChar modType = ' ');
     virtual QSize sizeHint() const;
     virtual QSizePolicy sizePolicy() const;
 
