@@ -2,9 +2,8 @@
  * @file lfowidget.cpp
  * @brief Implements the LfoWidget GUI class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -36,6 +35,7 @@
 #include "pixmaps/lfowtri.xpm"
 #include "pixmaps/lfowsquare.xpm"
 #include "pixmaps/lfowcustm.xpm"
+#include "pixmaps/lfowflip.xpm"
 #include "pixmaps/seqrecord.xpm"
 #include "config.h"
 
@@ -43,164 +43,21 @@
 #ifdef APPBUILD
 LfoWidget::LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
     int portCount, bool compactStyle,
-    bool mutedAdd, bool inOutVisible, const QString& name, QWidget *parent):
-    QWidget(parent),
-    midiWorker(p_midiWorker),
-    globStore(p_globStore),
-    modified(false)
+    bool mutedAdd, bool inOutVisible, const QString& p_name):
+    InOutBox(p_midiWorker, p_globStore, portCount, compactStyle, inOutVisible, p_name),
+    midiWorker(p_midiWorker)
 {
-    midiControl = new MidiControl(this);
-    manageBox = new ManageBox("LFO:", true, this);
 #else
 LfoWidget::LfoWidget(
     bool compactStyle,
-    bool mutedAdd, bool inOutVisible, QWidget *parent):
-    QWidget(parent),
-    modified(false)
+    bool mutedAdd, bool inOutVisible):
+    InOutBox(compactStyle, inOutVisible, "LFO:"),
+    midiWorker(NULL)
 {
-    midiWorker = NULL;
 #endif
-    int l1;
-
-    // Input group box on right top
-    QGroupBox *inBox = new QGroupBox(tr("Input"), this);
-
-    QLabel *enableNoteOffLabel = new QLabel(tr("&Note Off"),inBox);
-    enableNoteOff = new QCheckBox(this);
-    connect(enableNoteOff, SIGNAL(toggled(bool)), this, SLOT(updateEnableNoteOff(bool)));
-    enableNoteOffLabel->setBuddy(enableNoteOff);
-    enableNoteOff->setToolTip(tr("Stop output when Note is released"));
-
-    QLabel *enableRestartByKbdLabel = new QLabel(tr("&Restart"),inBox);
-    enableRestartByKbd = new QCheckBox(this);
-    connect(enableRestartByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableRestartByKbd(bool)));
-    enableRestartByKbdLabel->setBuddy(enableRestartByKbd);
-    enableRestartByKbd->setToolTip(tr("Restart sequence when a new note is received"));
-
-    QLabel *enableTrigByKbdLabel = new QLabel(tr("&Trigger"),inBox);
-    enableTrigByKbd = new QCheckBox(this);
-    connect(enableTrigByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableTrigByKbd(bool)));
-    enableTrigByKbdLabel->setBuddy(enableTrigByKbd);
-    enableTrigByKbd->setToolTip(tr("Retrigger sequence when a new note is received"));
-
-    QLabel *enableTrigLegatoLabel = new QLabel(tr("&Legato"),inBox);
-    enableTrigLegato = new QCheckBox(this);
-    connect(enableTrigLegato, SIGNAL(toggled(bool)), this, SLOT(updateTrigLegato(bool)));
-    enableTrigLegatoLabel->setBuddy(enableTrigLegato);
-    enableTrigLegato->setToolTip(tr("Retrigger / restart upon new legato note as well"));
-
-    enableNoteOff->setChecked(false);
-    enableRestartByKbd->setChecked(false);
-    enableTrigByKbd->setChecked(false);
-    enableTrigLegato->setChecked(false);
-
-    QLabel *ccnumberInLabel = new QLabel(tr("MIDI &CC#"), inBox);
-    ccnumberInBox = new QSpinBox(inBox);
-    ccnumberInLabel->setBuddy(ccnumberInBox);
-    ccnumberInBox->setRange(0, 127);
-    ccnumberInBox->setKeyboardTracking(false);
-    ccnumberInBox->setValue(74);
-    ccnumberInBox->setToolTip(tr("MIDI Controller number to record"));
-    connect(ccnumberInBox, SIGNAL(valueChanged(int)), this,
-            SLOT(updateCcnumberIn(int)));
-
-
-    QLabel *chInLabel = new QLabel(tr("&Channel"), inBox);
-    chIn = new QComboBox(inBox);
-    for (l1 = 0; l1 < 16; l1++) chIn->addItem(QString::number(l1 + 1));
-    chInLabel->setBuddy(chIn);
-    connect(chIn, SIGNAL(activated(int)), this, SLOT(updateChIn(int)));
-
-    QGridLayout *inBoxLayout = new QGridLayout;
-
-    inBoxLayout->addWidget(ccnumberInLabel, 0, 0);
-    inBoxLayout->addWidget(ccnumberInBox, 0, 1);
-    inBoxLayout->addWidget(enableNoteOffLabel, 1, 0);
-    inBoxLayout->addWidget(enableNoteOff, 1, 1);
-    inBoxLayout->addWidget(enableRestartByKbdLabel, 2, 0);
-    inBoxLayout->addWidget(enableRestartByKbd, 2, 1);
-    inBoxLayout->addWidget(enableTrigByKbdLabel, 3, 0);
-    inBoxLayout->addWidget(enableTrigByKbd, 3, 1);
-    inBoxLayout->addWidget(enableTrigLegatoLabel, 4, 0);
-    inBoxLayout->addWidget(enableTrigLegato, 4, 1);
-    inBoxLayout->addWidget(chInLabel, 5, 0);
-    inBoxLayout->addWidget(chIn, 5, 1);
-    if (compactStyle) {
-        inBoxLayout->setSpacing(1);
-        inBoxLayout->setMargin(2);
-    }
-
-    inBox->setLayout(inBoxLayout);
-
-    // Output group box on right side
-    QGroupBox *portBox = new QGroupBox(tr("Output"), this);
-
-    QLabel *ccnumberLabel = new QLabel(tr("MIDI &CC#"), portBox);
-    ccnumberBox = new QSpinBox(portBox);
-    ccnumberLabel->setBuddy(ccnumberBox);
-    ccnumberBox->setRange(0, 127);
-    ccnumberBox->setKeyboardTracking(false);
-    ccnumberBox->setValue(74);
-    ccnumberBox->setToolTip(tr("MIDI Controller number sent to output"));
-    connect(ccnumberBox, SIGNAL(valueChanged(int)), this,
-            SLOT(updateCcnumber(int)));
-
-
-    QLabel *channelLabel = new QLabel(tr("C&hannel"), portBox);
-    channelOut = new QComboBox(portBox);
-    channelLabel->setBuddy(channelOut);
-    for (l1 = 0; l1 < 16; l1++) channelOut->addItem(QString::number(l1 + 1));
-    connect(channelOut, SIGNAL(activated(int)), this,
-            SLOT(updateChannelOut(int)));
-
-
-    QGridLayout *portBoxLayout = new QGridLayout;
-    portBoxLayout->addWidget(ccnumberLabel, 0, 0);
-    portBoxLayout->addWidget(ccnumberBox, 0, 1);
-#ifdef APPBUILD
-        QLabel *portLabel = new QLabel(tr("&Port"), portBox);
-        portOut = new QComboBox(portBox);
-        portLabel->setBuddy(portOut);
-        for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
-        connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
-        portBoxLayout->addWidget(portLabel, 1, 0);
-        portBoxLayout->addWidget(portOut, 1, 1);
-#endif
-    portBoxLayout->addWidget(channelLabel, 2, 0);
-    portBoxLayout->addWidget(channelOut, 2, 1);
-
-    QVBoxLayout* outputLayout = new QVBoxLayout;
-    outputLayout->addLayout(portBoxLayout);
-    if (compactStyle) {
-        outputLayout->setSpacing(1);
-        outputLayout->setMargin(2);
-    }
-
-    portBox->setLayout(outputLayout);
-
-    hideInOutBoxAction = new QAction(tr("&Show/hide in-out settings"), this);
-    QToolButton *hideInOutBoxButton = new QToolButton(this);
-    hideInOutBoxAction->setCheckable(true);
-    hideInOutBoxAction->setChecked(inOutVisible);
-    hideInOutBoxButton->setDefaultAction(hideInOutBoxAction);
-    hideInOutBoxButton->setFixedSize(10, 80);
-    hideInOutBoxButton->setArrowType (Qt::ArrowType(0));
-    connect(hideInOutBoxAction, SIGNAL(toggled(bool)), this, SLOT(setInOutBoxVisible(bool)));
-
-    QVBoxLayout *inOutBoxLayout = new QVBoxLayout;
-
-#ifdef APPBUILD
-    inOutBoxLayout->addWidget(manageBox);
-#endif
-    inOutBoxLayout->addWidget(inBox);
-    inOutBoxLayout->addWidget(portBox);
-    inOutBoxLayout->addStretch();
-    inOutBox = new QWidget(this);
-    inOutBox->setLayout(inOutBoxLayout);
-    inOutBox->setVisible(inOutVisible);
 
     // group box for wave setup
-    QGroupBox *waveBox = new QGroupBox(tr("Wave"), this);
+    QGroupBox *waveBox = new QGroupBox(tr("Wave"));
 
     screen = new LfoScreen(this);
     screen->setToolTip(
@@ -212,10 +69,10 @@ LfoWidget::LfoWidget(
     connect(screen, SIGNAL(mouseWheel(int)), this,
             SLOT(mouseWheel(int)));
 
-    cursor = new Cursor('L', this);
+    cursor = new Cursor('L');
 
-    QLabel *waveFormBoxLabel = new QLabel(tr("&Waveform"), waveBox);
-    waveFormBox = new QComboBox(waveBox);
+    QLabel *waveFormBoxLabel = new QLabel(tr("&Waveform"));
+    waveFormBox = new QComboBox;
     waveFormBoxLabel->setBuddy(waveFormBox);
     //loadWaveForms();
     waveFormBox->addItem(QPixmap(lfowsine_xpm),"");
@@ -234,9 +91,8 @@ LfoWidget::LfoWidget(
     midiControl->addMidiLearnMenu("WaveForm", waveFormBox, 3);
 #endif
 
-    QLabel *freqBoxLabel = new QLabel(tr("&Frequency"),
-            waveBox);
-    freqBox = new QComboBox(waveBox);
+    QLabel *freqBoxLabel = new QLabel(tr("&Frequency"));
+    freqBox = new QComboBox;
     freqBoxLabel->setBuddy(freqBox);
     QStringList names;
     names << "1/32" << "1/16" << "1/8" << "1/4"
@@ -253,9 +109,8 @@ LfoWidget::LfoWidget(
 #ifdef APPBUILD
     midiControl->addMidiLearnMenu("Frequency", freqBox, 4);
 #endif
-    QLabel *resBoxLabel = new QLabel(tr("&Resolution"),
-            waveBox);
-    resBox = new QComboBox(waveBox);
+    QLabel *resBoxLabel = new QLabel(tr("&Resolution"));
+    resBox = new QComboBox;
     resBoxLabel->setBuddy(resBox);
     names.clear();
     names << "1" << "2" << "4" << "8" << "16" << "32" << "64" << "96" << "192";
@@ -270,8 +125,8 @@ LfoWidget::LfoWidget(
 #ifdef APPBUILD
     midiControl->addMidiLearnMenu("Resolution", resBox, 6);
 #endif
-    QLabel *sizeBoxLabel = new QLabel(tr("&Length"), waveBox);
-    sizeBox = new QComboBox(waveBox);
+    QLabel *sizeBoxLabel = new QLabel(tr("&Length"));
+    sizeBox = new QComboBox;
     sizeBoxLabel->setBuddy(sizeBox);
     names.clear();
     names << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8"
@@ -286,7 +141,7 @@ LfoWidget::LfoWidget(
 #ifdef APPBUILD
     midiControl->addMidiLearnMenu("Size", sizeBox, 7);
 #endif
-    loopBox = new QComboBox(waveBox);
+    loopBox = new QComboBox;
     names.clear();
     names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-" << "RANDM";
     loopBox->insertItems(0, names);
@@ -298,30 +153,20 @@ LfoWidget::LfoWidget(
 #ifdef APPBUILD
     midiControl->addMidiLearnMenu("LoopMode", loopBox, 8);
 #endif
-    muteOutAction = new QAction(tr("&Mute"),this);
-    muteOutAction->setCheckable(true);
-    connect(muteOutAction, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)));
-    muteOut = new QToolButton(this);
-    muteOut->setDefaultAction(muteOutAction);
-    muteOut->setFont(QFont("Helvetica", 8));
-    muteOut->setMinimumSize(QSize(35,20));
-#ifdef APPBUILD
-    midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
-#endif
-    deferChangesAction = new QAction("D", this);
-    deferChangesAction->setToolTip(tr("Defer mute to pattern end"));
-    deferChangesAction->setCheckable(true);
-    connect(deferChangesAction, SIGNAL(toggled(bool)), this, SLOT(updateDeferChanges(bool)));
 
-    QToolButton *deferChangesButton = new QToolButton(this);
-    deferChangesButton->setDefaultAction(deferChangesAction);
-    deferChangesButton->setFixedSize(20, 20);
+    flipWaveVerticalAction = new QAction(QPixmap(lfowflip_xpm),tr("&Flip"), this);
+    flipWaveVerticalAction->setToolTip(tr("Do a vertical flip of the wave about its mid value"));
+    connect(flipWaveVerticalAction, SIGNAL(triggered(bool)), this, SLOT(updateFlipWaveVertical()));
 
-    QLabel *recordButtonLabel = new QLabel(tr("Re&cord"), waveBox);
-    recordAction = new QAction(QPixmap(seqrecord_xpm), tr("Re&cord"), waveBox);
+    QToolButton *flipWaveVerticalButton = new QToolButton;
+    flipWaveVerticalButton->setDefaultAction(flipWaveVerticalAction);
+    flipWaveVerticalButton->setFixedSize(20, 20);
+
+    QLabel *recordButtonLabel = new QLabel(tr("Re&cord"));
+    recordAction = new QAction(QPixmap(seqrecord_xpm), tr("Re&cord"), this);
     recordAction->setToolTip(tr("Record incoming controller"));
     recordAction->setCheckable(true);
-    QToolButton *recordButton = new QToolButton(waveBox);
+    QToolButton *recordButton = new QToolButton;
     recordButton->setDefaultAction(recordAction);
     recordButtonLabel->setBuddy(recordButton);
     connect(recordAction, SIGNAL(toggled(bool)), this, SLOT(setRecord(bool)));
@@ -329,7 +174,7 @@ LfoWidget::LfoWidget(
     midiControl->addMidiLearnMenu("RecordToggle", recordButton, 5);
 #endif
     amplitude = new Slider(0, 127, 1, 8, 64, Qt::Horizontal,
-            tr("&Amplitude"), waveBox);
+            tr("&Amplitude"), this);
     connect(amplitude, SIGNAL(valueChanged(int)), this,
             SLOT(updateAmp(int)));
 #ifdef APPBUILD
@@ -337,7 +182,7 @@ LfoWidget::LfoWidget(
 #endif
 
     offset = new Slider(0, 127, 1, 8, 0, Qt::Horizontal,
-            tr("&Offset"), waveBox);
+            tr("&Offset"), this);
     connect(offset, SIGNAL(valueChanged(int)), this,
             SLOT(updateOffs(int)));
 #ifdef APPBUILD
@@ -366,7 +211,8 @@ LfoWidget::LfoWidget(
     paramBoxLayout->addWidget(resBox, 0, 5);
     paramBoxLayout->addWidget(sizeBoxLabel, 1, 4);
     paramBoxLayout->addWidget(sizeBox, 1, 5);
-    paramBoxLayout->setColumnStretch(6, 6);
+    paramBoxLayout->addWidget(flipWaveVerticalButton, 0, 6);
+    paramBoxLayout->setColumnStretch(7, 7);
 
     if (compactStyle) {
         paramBoxLayout->setSpacing(1);
@@ -388,29 +234,12 @@ LfoWidget::LfoWidget(
     QHBoxLayout *widgetLayout = new QHBoxLayout;
     widgetLayout->addWidget(waveBox, 1);
     widgetLayout->addWidget(hideInOutBoxButton, 0);
-    widgetLayout->addWidget(inOutBox, 0);
-#ifdef APPBUILD
-        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
-        midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 9);
-        connect(parStore, SIGNAL(store(int, bool)),
-                 this, SLOT(storeParams(int, bool)));
-        connect(parStore, SIGNAL(restore(int)),
-                 this, SLOT(restoreParams(int)));
-#endif
+    widgetLayout->addWidget(inOutBoxWidget, 0);
 
     muteOutAction->setChecked(mutedAdd);
 
     setLayout(widgetLayout);
     updateAmp(64);
-    dataChanged = false;
-    needsGUIUpdate = false;
-}
-
-LfoWidget::~LfoWidget()
-{
-#ifdef APPBUILD
-    delete parStore;
-#endif
 }
 
 #ifdef APPBUILD
@@ -423,37 +252,9 @@ void LfoWidget::writeData(QXmlStreamWriter& xml)
 {
     QByteArray tempArray;
     int l1;
-    xml.writeStartElement(manageBox->name.left(3));
-    xml.writeAttribute("name", manageBox->name.mid(manageBox->name.indexOf(':') + 1));
-    xml.writeAttribute("inOutVisible", QString::number(inOutBox->isVisible()));
-        xml.writeStartElement("input");
-            xml.writeTextElement("enableNoteOff", QString::number(
-                midiWorker->enableNoteOff));
-            xml.writeTextElement("restartByKbd", QString::number(
-                midiWorker->restartByKbd));
-            xml.writeTextElement("trigByKbd", QString::number(
-                midiWorker->trigByKbd));
-            xml.writeTextElement("trigLegato", QString::number(
-                midiWorker->trigLegato));
-            xml.writeTextElement("channel", QString::number(
-                midiWorker->chIn));
-            xml.writeTextElement("ccnumber", QString::number(
-                midiWorker->ccnumberIn));
-        xml.writeEndElement();
-
-        xml.writeStartElement("output");
-            xml.writeTextElement("muted", QString::number(
-                midiWorker->isMuted));
-            xml.writeTextElement("defer", QString::number(
-                midiWorker->deferChanges));
-            xml.writeTextElement("port", QString::number(
-                midiWorker->portOut));
-            xml.writeTextElement("channel", QString::number(
-                midiWorker->channelOut));
-            xml.writeTextElement("ccnumber", QString::number(
-                midiWorker->ccnumber));
-        xml.writeEndElement();
 
+        writeCommonData(xml);
+    
         xml.writeStartElement("waveParams");
             xml.writeTextElement("loopmode", QString::number(
                 loopBox->currentIndex()));
@@ -491,9 +292,6 @@ void LfoWidget::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("data", tempArray.toHex());
         xml.writeEndElement();
 
-        midiControl->writeData(xml);
-
-        parStore->writeData(xml);
     xml.writeEndElement();
 }
 
@@ -507,57 +305,10 @@ void LfoWidget::readData(QXmlStreamReader& xml)
         xml.readNext();
         if (xml.isEndElement())
             break;
+        
+        readCommonData(xml);
 
-        if (xml.isStartElement() && (xml.name() == "input")) {
-            while (!xml.atEnd()) {
-                xml.readNext();
-                if (xml.isEndElement())
-                    break;
-                if (xml.name() == "enableNoteOff")
-                    enableNoteOff->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "restartByKbd")
-                    enableRestartByKbd->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "trigByKbd")
-                    enableTrigByKbd->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "trigLegato")
-                    enableTrigLegato->setChecked(xml.readElementText().toInt());
-                if (xml.name() == "channel") {
-                    tmp = xml.readElementText().toInt();
-                    chIn->setCurrentIndex(tmp);
-                    updateChIn(tmp);
-                }
-                else if (xml.name() == "ccnumber")
-                    ccnumberInBox->setValue(xml.readElementText().toInt());
-                else skipXmlElement(xml);
-            }
-        }
-
-        if (xml.isStartElement() && (xml.name() == "output")) {
-            while (!xml.atEnd()) {
-                xml.readNext();
-                if (xml.isEndElement())
-                    break;
-                if (xml.name() == "muted")
-                    muteOutAction->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "defer")
-                    deferChangesAction->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "channel") {
-                    tmp = xml.readElementText().toInt();
-                    channelOut->setCurrentIndex(tmp);
-                    updateChannelOut(tmp);
-                }
-                else if (xml.name() == "port") {
-                    tmp = xml.readElementText().toInt();
-                    portOut->setCurrentIndex(tmp);
-                    updatePortOut(tmp);
-                }
-                else if (xml.name() == "ccnumber")
-                    ccnumberBox->setValue(xml.readElementText().toInt());
-                else skipXmlElement(xml);
-            }
-        }
-
-        else if (xml.isStartElement() && (xml.name() == "waveParams")) {
+        if (xml.isStartElement() && (xml.name() == "waveParams")) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
@@ -628,14 +379,12 @@ void LfoWidget::readData(QXmlStreamReader& xml)
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "midiControllers")) {
-            midiControl->readData(xml);
-        }
-        else if (xml.isStartElement() && (xml.name() == "globalStores")) {
-            parStore->readData(xml);
-        }
         else skipXmlElement(xml);
     }
+    
+    updateChIn(chIn->currentIndex());
+    updateChannelOut(channelOut->currentIndex());
+    updatePortOut(portOut->currentIndex());
     waveFormBox->setCurrentIndex(wvtmp);
     updateWaveForm(wvtmp);
     modified = false;
@@ -648,54 +397,6 @@ void LfoWidget::loadWaveForms()
         << tr("Saw down") << tr("Square") << tr("Custom");
 }
 
-void LfoWidget::updateCcnumber(int val)
-{
-    if (midiWorker)
-        midiWorker->ccnumber = val;
-    modified = true;
-}
-
-void LfoWidget::setChIn(int value)
-{
-    chIn->setCurrentIndex(value);
-    modified = true;
-}
-
-void LfoWidget::updateChIn(int val)
-{
-    if (midiWorker) midiWorker->chIn = val;
-    modified = true;
-}
-
-void LfoWidget::updateCcnumberIn(int val)
-{
-    if (midiWorker) midiWorker->ccnumberIn = val;
-    modified = true;
-}
-void LfoWidget::updateEnableNoteOff(bool on)
-{
-    if (midiWorker) midiWorker->enableNoteOff = on;
-    modified = true;
-}
-
-void LfoWidget::updateEnableRestartByKbd(bool on)
-{
-    if (midiWorker) midiWorker->restartByKbd = on;
-    modified = true;
-}
-
-void LfoWidget::updateEnableTrigByKbd(bool on)
-{
-    if (midiWorker) midiWorker->trigByKbd = on;
-    modified = true;
-}
-
-void LfoWidget::updateTrigLegato(bool on)
-{
-    if (midiWorker) midiWorker->trigLegato = on;
-    modified = true;
-}
-
 void LfoWidget::updateWaveForm(int val)
 {
     if (val > 5) return;
@@ -784,12 +485,23 @@ void LfoWidget::copyToCustom()
     modified = true;
 }
 
+void LfoWidget::updateFlipWaveVertical()
+{
+    if (midiWorker) {
+        if (waveFormBox->currentIndex() != 5) copyToCustom();
+        midiWorker->flipWaveVertical();
+        midiWorker->getData(&data);
+        screen->updateData(data);
+    }
+    modified = true;
+}
+
 void LfoWidget::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
 {
     if (!midiWorker) emit mouseSig(mouseX, mouseY, buttons, pressed);
     else midiWorker->mouseEvent(mouseX, mouseY, buttons, pressed);
 
-    if (waveFormBox->currentIndex() != 5) {
+    if ((buttons == 1) && (waveFormBox->currentIndex() != 5)) {
         waveFormBox->setCurrentIndex(5);
         updateWaveForm(5);
     }
@@ -804,106 +516,22 @@ void LfoWidget::mouseWheel(int step)
     offset->setValue(cv + step);
 }
 
-void LfoWidget::setInOutBoxVisible(bool on)
-{
-    inOutBox->setVisible(on);
-    modified=true;
-}
-
-void LfoWidget::setMuted(bool on)
-{
-    if (!midiWorker) return;
-    midiWorker->setMuted(on);
-    screen->setMuted(midiWorker->isMuted);
-#ifdef APPBUILD
-    parStore->ndc->setMuted(midiWorker->isMuted);
-#endif
-    modified = true;
-}
-
-void LfoWidget::updateDeferChanges(bool on)
-{
-    if (midiWorker) midiWorker->updateDeferChanges(on);
-    modified = true;
-}
-
 void LfoWidget::setRecord(bool on)
 {
     if (midiWorker) midiWorker->setRecordMode(on);
     screen->setRecordMode(on);
 }
 
-void LfoWidget::setPortOut(int value)
-{
-    portOut->setCurrentIndex(value);
-    modified = true;
-}
-
-void LfoWidget::setChannelOut(int value)
-{
-    channelOut->setCurrentIndex(value);
-    modified = true;
-}
-
-void LfoWidget::updatePortOut(int value)
-{
-    if (midiWorker) midiWorker->portOut = value;
-    modified = true;
-}
-
-void LfoWidget::updateChannelOut(int value)
-{
-    if (midiWorker) midiWorker->channelOut = value;
-    modified = true;
-}
-
-void LfoWidget::storeParams(int ix, bool empty)
-{
-#ifdef APPBUILD
-    // have to do this for moc not caring for APPBUILD flag
-    doStoreParams(ix, empty);
-#else
-    (void)ix;
-    (void)empty;
-#endif
-}
-
-void LfoWidget::restoreParams(int ix)
-{
-#ifdef APPBUILD
-    // have to do this for moc not caring for APPBUILD flag
-    doRestoreParams(ix);
-#else
-    (void)ix;
-#endif
-}
-
 #ifdef APPBUILD
 QVector<Sample> LfoWidget::getCustomWave()
 {
     return midiWorker->customWave;
 }
 
-bool LfoWidget::isModified()
+void LfoWidget::doStoreParams(int ix)
 {
-    return (modified || midiControl->isModified());
-}
-
-void LfoWidget::setModified(bool m)
-{
-    modified = m;
-    midiControl->setModified(m);
-}
-
-void LfoWidget::doStoreParams(int ix, bool empty)
-{
-    parStore->temp.empty = empty;
-    parStore->temp.muteOut = muteOut->isChecked();
-    parStore->temp.chIn = chIn->currentIndex();
     parStore->temp.ccnumberIn = ccnumberInBox->value();
     parStore->temp.ccnumber = ccnumberBox->value();
-    parStore->temp.channelOut = channelOut->currentIndex();
-    parStore->temp.portOut = portOut->currentIndex();
     parStore->temp.res = resBox->currentIndex();
     parStore->temp.size = sizeBox->currentIndex();
     parStore->temp.loopMode = loopBox->currentIndex();
@@ -939,17 +567,10 @@ void LfoWidget::doRestoreParams(int ix)
     updateLoop(parStore->list.at(ix).loopMode);
     updateWaveForm(parStore->list.at(ix).waveForm);
     if (!parStore->onlyPatternList.at(ix)) {
-        //muteOut->setChecked(parStore->list.at(ix).muteOut);
+        amplitude->setValue(parStore->list.at(ix).ampl);
         offset->setValue(parStore->list.at(ix).offs);
-        chIn->setCurrentIndex(parStore->list.at(ix).chIn);
-        updateChIn(parStore->list.at(ix).chIn);
         ccnumberInBox->setValue(parStore->list.at(ix).ccnumberIn);
         ccnumberBox->setValue(parStore->list.at(ix).ccnumber);
-        channelOut->setCurrentIndex(parStore->list.at(ix).channelOut);
-        updateChannelOut(parStore->list.at(ix).channelOut);
-        setPortOut(parStore->list.at(ix).portOut);
-        updatePortOut(parStore->list.at(ix).portOut);
-        amplitude->setValue(parStore->list.at(ix).ampl);
     }
     midiWorker->setFramePtr(0);
 }
@@ -963,6 +584,15 @@ void LfoWidget::copyParamsFrom(LfoWidget *fromWidget)
     enableTrigByKbd->setChecked(fromWidget->enableTrigByKbd->isChecked());
     enableTrigLegato->setChecked(fromWidget->enableTrigLegato->isChecked());
 
+    for (int l1 = 0; l1 < 1; l1++) {
+        tmp = fromWidget->indexIn[l1]->value();
+        indexIn[l1]->setValue(tmp);
+    }
+    for (int l1 = 0; l1 < 1; l1++) {
+        tmp = fromWidget->rangeIn[l1]->value();
+        rangeIn[l1]->setValue(tmp);
+    }
+
     tmp = fromWidget->chIn->currentIndex();
     chIn->setCurrentIndex(tmp);
     updateChIn(tmp);
@@ -975,10 +605,8 @@ void LfoWidget::copyParamsFrom(LfoWidget *fromWidget)
 
     tmp = fromWidget->ccnumberInBox->value();
     ccnumberInBox->setValue(tmp);
-    updateCcnumberIn(tmp);
     tmp = fromWidget->ccnumberBox->value();
     ccnumberBox->setValue(tmp);
-    updateCcnumber(tmp);
 
     tmp = fromWidget->resBox->currentIndex();
     resBox->setCurrentIndex(tmp);
@@ -1121,7 +749,9 @@ void LfoWidget::updateDisplay()
 
     if (!(needsGUIUpdate || midiWorker->needsGUIUpdate)) return;
 
-    muteOutAction->setChecked(midiWorker->isMuted);
+    muteOut->setChecked(midiWorker->isMuted);
+    screen->newGrooveValues(midiWorker->newGrooveTick, midiWorker->grooveVelocity,
+                midiWorker->grooveLength);   
     screen->setMuted(midiWorker->isMuted);
     parStore->ndc->setMuted(midiWorker->isMuted);
     recordAction->setChecked(midiWorker->recordMode);
@@ -1143,20 +773,4 @@ void LfoWidget::updateDisplay()
     midiWorker->needsGUIUpdate = false;
 }
 
-void LfoWidget::skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
-
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
 #endif
