@@ -2,9 +2,8 @@
  * @file lfowidget.h
  * @brief Member definitions for the LfoWidget GUI class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -36,14 +35,8 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-#ifdef APPBUILD
-#include "globstore.h"
-#include "midicontrol.h"
-#include "managebox.h"
-#include "parstore.h"
-#endif
-
 #include "midilfo.h"
+#include "inoutbox.h"
 #include "cursor.h"
 #include "slider.h"
 #include "lfoscreen.h"
@@ -59,17 +52,11 @@
  *
  *
 */
-class LfoWidget : public QWidget
+class LfoWidget : public InOutBox
 {
     Q_OBJECT
 
     MidiLfo *midiWorker;
-#ifdef APPBUILD
-    GlobStore *globStore;
-#endif
-    bool modified;              /**< Is set to True if unsaved parameter modifications exist */
-    bool dataChanged;
-    bool needsGUIUpdate;
 /*!
 * @brief populates the LfoWidget::waveForms list with
 * waveform names.
@@ -92,75 +79,42 @@ class LfoWidget : public QWidget
  * @brief Constructor for LfoWidget. It creates the GUI and an LfoScreen
  * instance.
  *
- * @param *p_midiWorker Pointer to the associated MidiLfo object
- * @param *p_globStore Pointer to the GlobStore widget
+ * @param p_midiWorker Associated MidiLfo Object
+ * @param p_globStore The Application-wide globStore widget
  * @param portCount Number of available MIDI output ports
  * @param compactStyle If set to True, Widget will use reduced spacing and small fonts
  * @param mutedAdd If set to True, the module will be added in muted state
- * @param inOutVisible If set to True, the module will show its In-Out panel
- * @param name Name string of the module
- * @param parent The parent widget of this module, i.e. MainWindow
+ * @param inOutVisible Add the module with visible InOutBox or not
+ * @param name The name of the module preceded by its type (Arp: , etc...)
  */
     LfoWidget(MidiLfo *p_midiWorker, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
-            const QString& name = "", QWidget* parent=0);
+            const QString& name = "");
 
-    ParStore *parStore;
-    MidiControl *midiControl;
-    ManageBox *manageBox;
 #else
     LfoWidget(
             bool compactStyle,
-            bool mutedAdd = false, bool inOutVisible = true,
-            QWidget* parent=0);
+            bool mutedAdd = false, bool inOutVisible = true);
 #endif
 
-    ~LfoWidget();
     LfoScreen *screen;
     Cursor *cursor;
     QVector<Sample> data;
     QStringList waveForms;
-    QComboBox *chIn;
-    QSpinBox  *ccnumberInBox;
-    QSpinBox  *ccnumberBox;
-    QComboBox *channelOut, *portOut;
     QComboBox *resBox, *sizeBox;
     QComboBox *loopBox;
-    QWidget *inOutBox;
-    QCheckBox *enableNoteOff;
-    QCheckBox *enableRestartByKbd;
-    QCheckBox *enableTrigByKbd;
-    QCheckBox *enableTrigLegato;
     Slider *frequency, *amplitude, *offset;
     QAction *recordAction;
-    QAction* hideInOutBoxAction;
-    QAction *muteOutAction;
-    QAction *deferChangesAction;
-    QToolButton *muteOut;
+    QAction *flipWaveVerticalAction;
     QComboBox *waveFormBox, *freqBox;
 
-    void setChIn(int value);
     QVector<Sample> getCustomWave();
     int resBoxIndex;
     int sizeBoxIndex;
     int freqBoxIndex;
     int waveFormBoxIndex;
 
-/*!
-* @brief Setter for the LfoWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
-*
-*/
-    void setChannelOut(int value);
-/*!
-* @brief Setter for the LfoWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void setPortOut(int value);
 
 #ifdef APPBUILD
 /*!
@@ -191,33 +145,11 @@ class LfoWidget : public QWidget
 * @param fromWidget pointer to the LfoWidget parameters are to be taken from
 */
     void copyParamsFrom(LfoWidget *fromWidget);
-/*!
-* @brief Accessor for LfoWidget::modified.
-* @return True if unsaved parameter modifications exist
-*
-*/
-    bool isModified();
-/*!
-* @brief sets LfoWidget::modified.
-* @param m Set to True if unsaved parameter modifications appear
-*
-*/
-    void setModified(bool);
-    void skipXmlElement(QXmlStreamReader& xml);
-/*!
-* @brief stores some module parameters in a parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
-    void doStoreParams(int ix, bool empty);
-/*!
-* @brief restores some module parameters from the parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
+
+    void doStoreParams(int ix);
     void doRestoreParams(int ix);
+    void updateDisplay();
+    void handleController(int ccnumber, int channel, int value);
 #endif
 
 /* SIGNALS */
@@ -230,15 +162,8 @@ class LfoWidget : public QWidget
 
 /* PUBLIC SLOTS */
   public slots:
-    void updateChIn(int value);
-    void updateCcnumberIn(int value);
     void updateScreen(int value);
     void setRecord(bool on);
-    void updateEnableNoteOff(bool on);
-    void updateEnableRestartByKbd(bool on);
-    void updateEnableTrigByKbd(bool on);
-    void updateTrigLegato(bool on);
-    void setInOutBoxVisible(bool on);
 
 /*!
 * @brief Slot for the LfoWidget::waveFormBox combobox setting the waveform
@@ -275,13 +200,6 @@ class LfoWidget : public QWidget
 */
     void updateLoop(int);
 /*!
-* @brief Slot for the LfoWidget::ccnumberBox spinbox setting the output
-* controller CC number of this module.
-* @param val CC number to send data to
-*
-*/
-    void updateCcnumber(int val);
-/*!
 * @brief Slot for the LfoWidget::freqBox combobox. Sets the frequency
 * of the LFO.
 *
@@ -351,59 +269,15 @@ class LfoWidget : public QWidget
     void copyToCustom();
 
 /*!
-* @brief Slot for the LfoWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
+* @brief Slot for the LfoWidget::flipWaveVerticalAction().
+*
+* If waveform is custom it calls the midi worker
+* MidiLfo::flipWaveVertical() function, which flips the MidiLfo::customWave
+* about its mid value.
 *
 */
-    void updateChannelOut(int value);
-/*!
-* @brief Slot for the LfoWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void updatePortOut(int value);
-/*!
-* @brief Slot for the LfoWidget::muteOut checkbox.
-* suppresses output of LFO data.
-*
-* It calls
-* MidiLfo::setMuted and LfoScreen::setMuted
-* @param on Set to True for muting this module
-*
-*/
-    void setMuted(bool on);
-/*!
-* @brief Slot for the LfoWidget::deferChanges action.
-*
-* Sets a flag in the midi worker causing parameter changes to become
-* active/inactive only at pattern end.
-*
-* @param on Set to True for deferring parameter changes to pattern end
-*/
-    void updateDeferChanges(bool on);
+    void updateFlipWaveVertical();
 
-    void storeParams(int ix, bool empty = false);
-    void restoreParams(int ix);
-
-#ifdef APPBUILD
-    void handleController(int ccnumber, int channel, int value);
-/*!
- * @brief Updates the LfoScreen and other GUI elements with data from
- * the MidiSeq instance.
- *
- * It is called by Engine::updateDisplay(), which itself is
- * connected to the MTimer::timeout event. It runs in the MTimer thread.
- * It reads the waveform data and other settings from the MidiLfo instance
- * and sets GUI cursor, wave display and other elements accordingly. This
- * way, no memory allocations are done within the jack run thread, for
- * instance by MIDI controllers, since the Qt widgets are not called directly.
- * This function also checks whether parameter chages from ParStore are
- * pending and causes them to get transferred if so.
- */
-    void updateDisplay();
-#endif
     int getFramePtr() { return midiWorker->getFramePtr(); }
     int getNextTick() { return midiWorker->nextTick; }
     bool getReverse() { return midiWorker->reverse; }
