@@ -2,9 +2,8 @@
  * @file lfowidget_lv2.cpp
  * @brief Implements the the LV2 GUI for the QMidiArp Lfo plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -32,7 +31,7 @@ LfoWidgetLV2::LfoWidgetLV2 (
         LV2UI_Controller ct,
         LV2UI_Write_Function write_function,
         const LV2_Feature *const *host_features)
-        : LfoWidget(true, true, true, 0)
+        : LfoWidget(true, true, true)
 {
     m_controller = ct;
     writeFunction = write_function;
@@ -73,9 +72,9 @@ LfoWidgetLV2::LfoWidgetLV2 (
     connect(transportBox, SIGNAL(toggled(bool)), tempoSpin, SLOT(setDisabled(bool)));
     transportBox->setChecked(true);
 
-    inOutBox->layout()->addWidget(transportBoxLabel);
-    inOutBox->layout()->addWidget(transportBox);
-    inOutBox->layout()->addWidget(tempoSpin);
+    inOutBoxWidget->layout()->addWidget(transportBoxLabel);
+    inOutBoxWidget->layout()->addWidget(transportBox);
+    inOutBoxWidget->layout()->addWidget(tempoSpin);
 
     connect(amplitude,          SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(offset,             SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
@@ -86,6 +85,10 @@ LfoWidgetLV2::LfoWidgetLV2 (
     connect(loopBox,            SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(channelOut,         SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(chIn,               SIGNAL(activated(int)), this, SLOT(mapParam(int)));
+    connect(indexIn[0],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(indexIn[1],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(rangeIn[0],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(rangeIn[1],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(ccnumberBox,        SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(ccnumberInBox,      SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(tempoSpin,          SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
@@ -98,6 +101,8 @@ LfoWidgetLV2::LfoWidgetLV2 (
     connect(recordAction,       SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
     connect(deferChangesAction, SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
 
+    connect(flipWaveVerticalAction, SIGNAL(triggered()), this, SLOT(sendFlipWaveVertical()));
+    
     connect(this, SIGNAL(mouseSig(double, double, int, int))
             , this, SLOT(mapMouse(double, double, int, int)));
 
@@ -113,6 +118,7 @@ LfoWidgetLV2::LfoWidgetLV2 (
     mouseXCur = 0.0;
     mouseYCur = 0.0;
     sendUIisUp(true);
+    copiedToCustomFlag = false;
 }
 
 LfoWidgetLV2::~LfoWidgetLV2()
@@ -128,15 +134,13 @@ void LfoWidgetLV2::port_event ( uint32_t port_index,
     if (!data.count()) sendUIisUp(true);
 
     if (format == uris->atom_eventTransfer
-      && atom->type == uris->atom_Blank) {
+      && atom->type == uris->atom_Object) {
         receiveWave(atom);
     }
     else if (format == 0 && buffer_size == sizeof(float)) {
 
 
         float fValue = *(float *) buffer;
-        res = resBox->currentText().toInt();
-        size = sizeBox->currentText().toInt();
 
         switch (port_index) {
             case AMPLITUDE:
@@ -160,6 +164,18 @@ void LfoWidgetLV2::port_event ( uint32_t port_index,
             case CH_IN:
                     chIn->setCurrentIndex(fValue);
             break;
+            case INDEX_IN1:
+                    indexIn[0]->setValue(fValue);
+            break;
+            case INDEX_IN2:
+                    indexIn[1]->setValue(fValue);
+            break;
+            case RANGE_IN1:
+                    rangeIn[0]->setValue(fValue);
+            break;
+            case RANGE_IN2:
+                    rangeIn[1]->setValue(fValue);
+            break;
             case CURSOR_POS:
                     cursor->updateNumbers(res, size);
                     cursor->updatePosition(fValue);
@@ -167,6 +183,9 @@ void LfoWidgetLV2::port_event ( uint32_t port_index,
             break;
             case WAVEFORM:
                     waveFormBox->setCurrentIndex(fValue);
+                    updateWaveForm(fValue);
+                    screen->updateData(data);
+                    screen->update();
             break;
             case LOOPMODE:
                     loopBox->setCurrentIndex(fValue);
@@ -231,17 +250,40 @@ void LfoWidgetLV2::sendUIisUp(bool on)
 
     if (on) state = uris->ui_up; else state=uris->ui_down;
 
-    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_blank(&forge, &frame, 1, state);
+    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_object(&forge, &frame, 1, state);
 
     /* close-off frame */
     lv2_atom_forge_pop(&forge, &frame);
     writeFunction(m_controller, MidiIn, lv2_atom_total_size(msg), uris->atom_eventTransfer, msg);
 }
 
+void LfoWidgetLV2::sendFlipWaveVertical()
+{
+    const QMidiArpURIs* uris = &m_uris;
+    uint8_t obj_buf[64];
+    int state;
+
+    LV2_Atom_Forge_Frame frame;
+    lv2_atom_forge_frame_time(&forge, 0);
+
+    /* prepare forge buffer and initialize atom-sequence */
+    lv2_atom_forge_set_buffer(&forge, obj_buf, 16);
+
+    state = uris->flip_wave;
+
+    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_object(&forge, &frame, 1, state);
+
+    /* close-off frame */
+    lv2_atom_forge_pop(&forge, &frame);
+    writeFunction(m_controller, MidiIn, lv2_atom_total_size(msg), uris->atom_eventTransfer, msg);        
+    if (waveFormBox->currentIndex() != 5) copiedToCustomFlag = true;
+}
+
 void LfoWidgetLV2::receiveWave(LV2_Atom* atom)
 {
     QMidiArpURIs* const uris = &m_uris;
-    if (atom->type != uris->atom_Blank) return;
+    if ( (atom->type != uris->atom_Blank) 
+            && (atom->type != uris->atom_Object)) return;
 
     /* cast the buffer to Atom Object */
     LV2_Atom_Object* obj = (LV2_Atom_Object*)atom;
@@ -260,6 +302,8 @@ void LfoWidgetLV2::receiveWave(LV2_Atom* atom)
     /* typecast, dereference pointer to vector */
     const int *recdata = (int*) LV2_ATOM_BODY(&voi->atom);
     int ofs = 127;
+    res = resBox->currentText().toInt();
+    size = sizeBox->currentText().toInt();
     for (uint l1 = 0; l1 < n_elem; l1++) {
         receiveWavePoint(l1, recdata[l1]);
         if ((l1 < n_elem - 1) && (recdata[l1] > -1) && (recdata[l1] < ofs)) ofs = recdata[l1];
@@ -270,6 +314,13 @@ void LfoWidgetLV2::receiveWave(LV2_Atom* atom)
         offset->setValue(ofs);
         offset->valueChangedSignalSuppressed = false;
     }
+    if (copiedToCustomFlag) {
+        waveFormBox->setCurrentIndex(5);
+        updateWaveForm(5);
+        updateParam(WAVEFORM, 5);
+        copiedToCustomFlag = false;
+    }
+
     screen->updateData(data);
     screen->update();
 }
@@ -291,7 +342,10 @@ void LfoWidgetLV2::receiveWavePoint(int index, int value)
 void LfoWidgetLV2::mapBool(bool on)
 {
     float value = (float)on;
-    if (muteOutAction == sender())              updateParam(MUTE, value);
+    if (muteOutAction == sender()) {
+        updateParam(MUTE, value);
+        screen->setMuted(value);
+    }
     else if (enableNoteOff == sender())         updateParam(ENABLE_NOTEOFF, value);
     else if (enableRestartByKbd == sender())    updateParam(ENABLE_RESTARTBYKBD, value);
     else if (enableTrigByKbd == sender())       updateParam(ENABLE_TRIGBYKBD, value);
@@ -310,11 +364,11 @@ void LfoWidgetLV2::mapMouse(double mouseX, double mouseY, int buttons, int press
     /* in case we get a mouse click and waveform is not "custom", the
      * backend will perform copyToCustom(), and we have to set the
      * index to custom here as well */
-    if (pressed && waveFormBox->currentIndex() != 5) {
+    if ((buttons == 1) && pressed && waveFormBox->currentIndex() != 5) {
         waveFormBox->setCurrentIndex(5);
         updateWaveForm(5);
     }
-    if (!pressed) updateParam(WAVEFORM, 5);
+    if ((!pressed) && (buttons == 1)) updateParam(WAVEFORM, 5);
 }
 
 void LfoWidgetLV2::mapParam(int value)
@@ -326,6 +380,10 @@ void LfoWidgetLV2::mapParam(int value)
     else if (freqBox == sender())       updateParam(FREQUENCY, value);
     else if (channelOut == sender())    updateParam(CH_OUT, value);
     else if (chIn == sender())          updateParam(CH_IN, value);
+    else if (indexIn[0] == sender())    updateParam(INDEX_IN1, value);
+    else if (indexIn[1] == sender())    updateParam(INDEX_IN2, value);
+    else if (rangeIn[0] == sender())    updateParam(RANGE_IN1, value);
+    else if (rangeIn[1] == sender())    updateParam(RANGE_IN2, value);
     else if (waveFormBox == sender())   updateParam(WAVEFORM, value);
     else if (loopBox == sender())       updateParam(LOOPMODE, value);
     else if (ccnumberBox == sender())   updateParam(CC_OUT, value);
