@@ -2,9 +2,8 @@
  * @file lfowidget_lv2.h
  * @brief Headers for the LV2 GUI for the QMidiArp Lfo plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -59,19 +58,23 @@ class LfoWidgetLV2 : public LfoWidget
             MOUSEPRESSED = 16,
             CC_OUT = 17,
             CC_IN = 18,
-            ENABLE_NOTEOFF = 19,
-            ENABLE_RESTARTBYKBD = 20,
-            ENABLE_TRIGBYKBD = 21,
-            ENABLE_TRIGLEGATO = 22,
-            RECORD = 23,
-            DEFER = 24,
-            SPARE = 25,
-            TRANSPORT_MODE = 26,
-            TEMPO = 27,
-            WaveOut = 28,
-            HOST_TEMPO = 29,
-            HOST_POSITION = 30,
-            HOST_SPEED = 31
+            INDEX_IN1 = 19,
+            INDEX_IN2 = 20,
+            RANGE_IN1 = 21,
+            RANGE_IN2 = 22,
+            ENABLE_NOTEOFF = 23,
+            ENABLE_RESTARTBYKBD = 24,
+            ENABLE_TRIGBYKBD = 25,
+            ENABLE_TRIGLEGATO = 26,
+            RECORD = 27,
+            DEFER = 28,
+            SPARE = 29,
+            TRANSPORT_MODE = 30,
+            TEMPO = 31,
+            WaveOut = 32,
+            HOST_TEMPO = 33,
+            HOST_POSITION = 34,
+            HOST_SPEED = 35
         };
 
     LfoWidgetLV2(
@@ -91,6 +94,7 @@ class LfoWidgetLV2 : public LfoWidget
     void mapMouse(double mouseX, double mouseY, int buttons, int pressed);
     void receiveWave(LV2_Atom* atom);
     void receiveWavePoint(int index, int value);
+    void sendFlipWaveVertical();
 
   protected:
     void updateParam(int index, float fValue) const;
@@ -107,6 +111,7 @@ class LfoWidgetLV2 : public LfoWidget
 
     int res, size;
     double mouseXCur, mouseYCur;
+    bool copiedToCustomFlag;
 };
 
 #endif
