@@ -2,9 +2,8 @@
  * @file lv2_common.h
  * @brief URI definitions and mapping for QMidiArp LV2 plugins
  *
- * @section LICENSE
  *
- *      Copyright 2011 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2011 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -63,6 +62,7 @@ typedef struct {
     LV2_URID pattern_string;
     LV2_URID ui_up;
     LV2_URID ui_down;
+    LV2_URID flip_wave;
 } QMidiArpURIs;
 
 static inline void map_uris(LV2_URID_Map* urid_map, QMidiArpURIs* uris) {
@@ -86,6 +86,6 @@ static inline void map_uris(LV2_URID_Map* urid_map, QMidiArpURIs* uris) {
     uris->hex_mutemask        = urid_map->map(urid_map->handle, QMIDIARP_LV2_PREFIX "MUTEHEX");
     uris->pattern_string      = urid_map->map(urid_map->handle, QMIDIARP_LV2_PREFIX "ARPPATTERN");
     uris->ui_up               = urid_map->map(urid_map->handle, QMIDIARP_LV2_PREFIX "UI_UP");
-    uris->ui_down             = urid_map->map(urid_map->handle, QMIDIARP_LV2_PREFIX "UI_DOWN");
+    uris->flip_wave           = urid_map->map(urid_map->handle, QMIDIARP_LV2_PREFIX "FLIP_WAVE");
 }
 #endif
