@@ -3,7 +3,7 @@
  *
  *   @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #ifndef __MAIN_H
 #define __MAIN_H
 
+#include <QXmlStreamReader>
 #include "midievent.h"
 
 #define CT_FOOTSW       0x40
@@ -79,4 +80,17 @@ const int seqResValues[5] = {1, 2, 4, 8, 16};
  */
 const int seqSizeValues[11] = {1, 2, 3, 4, 5, 6, 7, 8, 16, 32};
 
+#ifdef APPBUILD
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
+extern void skipXmlElement(QXmlStreamReader& xml);
+
+#endif
 #endif
