@@ -2,9 +2,8 @@
  * @file mainwindow.cpp
  * @brief Implements the MainWindow top-level UI class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -87,8 +86,8 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
     lastDir = QDir::homePath();
     alsaMidi = p_alsamidi;
 
-    grooveWidget = new GrooveWidget(this);
-    grooveWindow = new QDockWidget(tr("Groove"), this);
+    grooveWidget = new GrooveWidget;
+    grooveWindow = new QDockWidget(tr("Groove"));
     grooveWindow->setFeatures(QDockWidget::DockWidgetClosable
             | QDockWidget::DockWidgetMovable
             | QDockWidget::DockWidgetFloatable);
@@ -97,7 +96,7 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
     grooveWindow->setVisible(true);
 
     globStore = new GlobStore(this);
-    globStoreWindow = new QDockWidget(tr("Global Store"), this);
+    globStoreWindow = new QDockWidget(tr("Global Store"));
     globStoreWindow->setFeatures(QDockWidget::DockWidgetClosable
             | QDockWidget::DockWidgetMovable
             | QDockWidget::DockWidgetFloatable);
@@ -133,6 +132,7 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi, char *execName)
 #endif
 
     engine = new Engine(globStore, grooveWidget, p_portCount, alsaMidi, this);
+    
     if (alsaMidi) {
         connect(engine->jackSync, SIGNAL(j_shutdown()), this, SLOT(jackShutdown()));
     }
@@ -462,27 +462,26 @@ void MainWindow::seqNew()
     }
 }
 
-void MainWindow::addArp(const QString& name, bool fromfile, bool inOutVisible)
+void MainWindow::addArp(const QString& p_name, bool fromfile, bool inOutVisible)
 {
     int count, widgetID;
     MidiArp *midiWorker = new MidiArp();
     ArpWidget *moduleWidget = new ArpWidget(midiWorker, globStore,
             engine->getPortCount(), passWidget->compactStyle,
-            passWidget->mutedAdd, inOutVisible, name, this);
+            passWidget->mutedAdd, inOutVisible, p_name);
     connect(moduleWidget, SIGNAL(presetsChanged(const QString&, const
                     QString&, int)),
             this, SLOT(updatePatternPresets(const QString&, const
                     QString&, int)));
-    connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)),
+    connect(moduleWidget, SIGNAL(moduleRemove(int)),
             this, SLOT(removeArp(int)));
-    connect(moduleWidget->manageBox, SIGNAL(dockRename(const QString&, int, int)),
-            engine, SLOT(renameDock(const QString&, int, int)));
-    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            engine, SLOT(setMidiLearn(int, int, int)));
+    connect(moduleWidget, SIGNAL(dockRename(const QString&, int)),
+            engine, SLOT(renameDock(const QString&, int)));
+    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int)),
+            engine, SLOT(setMidiLearn(int, int)));
 
     widgetID = engine->arpWidgetCount();
-    moduleWidget->manageBox->name = name;
-    moduleWidget->manageBox->ID = widgetID;
+    moduleWidget->ID = widgetID;
     moduleWidget->midiControl->ID = widgetID;
 
     // if the module is added at a time when global stores are already
@@ -497,13 +496,11 @@ void MainWindow::addArp(const QString& name, bool fromfile, bool inOutVisible)
     engine->sendGroove();
 
     count = engine->moduleWindowCount();
-    moduleWidget->manageBox->parentDockID = count;
+    moduleWidget->parentDockID = count;
     moduleWidget->midiControl->parentDockID = count;
-    moduleWidget->setProperty("widgetID", widgetID);
-    appendDock(moduleWidget, name, count);
+    appendDock(moduleWidget, p_name, count);
     connect(moduleWidget->parStore->topButton, SIGNAL(pressed())
             , engine->moduleWindow(count), SLOT(raise()));
-
     checkIfFirstModule();
 }
 
@@ -514,14 +511,14 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
     MidiLfo *midiWorker = new MidiLfo();
     LfoWidget *moduleWidget = new LfoWidget(midiWorker, globStore,
             engine->getPortCount(), passWidget->compactStyle,
-            passWidget->mutedAdd, inOutVisible, p_name, this);
-    connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)),
+            passWidget->mutedAdd, inOutVisible, p_name);
+    connect(moduleWidget, SIGNAL(moduleRemove(int)),
             this, SLOT(removeLfo(int)));
-    connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneLfo(int)));
-    connect(moduleWidget->manageBox, SIGNAL(dockRename(const QString&, int, int)),
-            engine, SLOT(renameDock(const QString&, int, int)));
-    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            engine, SLOT(setMidiLearn(int, int, int)));
+    connect(moduleWidget, SIGNAL(moduleClone(int)), this, SLOT(cloneLfo(int)));
+    connect(moduleWidget, SIGNAL(dockRename(const QString&, int)),
+            engine, SLOT(renameDock(const QString&, int)));
+    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int)),
+            engine, SLOT(setMidiLearn(int, int)));
 
     widgetID = engine->lfoWidgetCount();
     if (clonefrom >= 0) {
@@ -529,8 +526,7 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
     }
 
     //TODO: transfer these items to constructor
-    moduleWidget->manageBox->name = p_name;
-    moduleWidget->manageBox->ID = widgetID;
+    moduleWidget->ID = widgetID;
     moduleWidget->midiControl->ID = widgetID;
 
     // if the module is added at a time when global stores are already
@@ -552,9 +548,8 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
     engine->sendGroove();
 
     count = engine->moduleWindowCount();
-    moduleWidget->manageBox->parentDockID = count;
+    moduleWidget->parentDockID = count;
     moduleWidget->midiControl->parentDockID = count;
-    moduleWidget->setProperty("widgetID", widgetID);
     appendDock(moduleWidget, p_name, count);
     connect(moduleWidget->parStore->topButton, SIGNAL(pressed())
             , engine->moduleWindow(count), SLOT(raise()));
@@ -569,20 +564,19 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
     MidiSeq *midiWorker = new MidiSeq();
     SeqWidget *moduleWidget = new SeqWidget(midiWorker, globStore,
             engine->getPortCount(), passWidget->compactStyle,
-            passWidget->mutedAdd, inOutVisible, p_name, this);
-    connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)), this, SLOT(removeSeq(int)));
-    connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneSeq(int)));
-    connect(moduleWidget->manageBox, SIGNAL(dockRename(const QString&, int, int)),
-            engine, SLOT(renameDock(const QString&, int, int)));
-    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
-            engine, SLOT(setMidiLearn(int, int, int)));
+            passWidget->mutedAdd, inOutVisible, p_name);
+    connect(moduleWidget, SIGNAL(moduleRemove(int)), this, SLOT(removeSeq(int)));
+    connect(moduleWidget, SIGNAL(moduleClone(int)), this, SLOT(cloneSeq(int)));
+    connect(moduleWidget, SIGNAL(dockRename(const QString&, int)),
+            engine, SLOT(renameDock(const QString&, int)));
+    connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int)),
+            engine, SLOT(setMidiLearn(int, int)));
 
     widgetID = engine->seqWidgetCount();
     if (clonefrom >= 0) {
         moduleWidget->copyParamsFrom(engine->seqWidget(clonefrom));
     }
-    moduleWidget->manageBox->name = p_name;
-    moduleWidget->manageBox->ID = widgetID;
+    moduleWidget->ID = widgetID;
     moduleWidget->midiControl->ID = widgetID;
 
     // if the module is added at a time when global stores are already
@@ -604,9 +598,8 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
     engine->sendGroove();
 
     count = engine->moduleWindowCount();
-    moduleWidget->manageBox->parentDockID = count;
+    moduleWidget->parentDockID = count;
     moduleWidget->midiControl->parentDockID = count;
-    moduleWidget->setProperty("widgetID", widgetID);
     appendDock(moduleWidget, p_name, count);
     connect(moduleWidget->parStore->topButton, SIGNAL(pressed())
             , engine->moduleWindow(count), SLOT(raise()));
@@ -616,14 +609,14 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
 void MainWindow::cloneLfo(int ID)
 {
     QString name;
-    name = engine->lfoWidget(ID)->manageBox->name + "_0";
+    name = engine->lfoWidget(ID)->name + "_0";
     addLfo(name, false, ID);
 }
 
 void MainWindow::cloneSeq(int ID)
 {
     QString name;
-    name = engine->seqWidget(ID)->manageBox->name + "_0";
+    name = engine->seqWidget(ID)->name + "_0";
     addSeq(name, false, ID);
 }
 
@@ -647,7 +640,7 @@ void MainWindow::removeArp(int index)
     int parentDockID;
     ArpWidget *arpWidget = engine->arpWidget(index);
 
-    parentDockID = arpWidget->manageBox->parentDockID;
+    parentDockID = arpWidget->parentDockID;
     QDockWidget *dockWidget = engine->moduleWindow(parentDockID);
     globStore->removeModule(parentDockID);
 
@@ -664,7 +657,7 @@ void MainWindow::removeLfo(int index)
     int parentDockID;
     LfoWidget *lfoWidget = engine->lfoWidget(index);
 
-    parentDockID = lfoWidget->manageBox->parentDockID;
+    parentDockID = lfoWidget->parentDockID;
     QDockWidget *dockWidget = engine->moduleWindow(parentDockID);
     globStore->removeModule(parentDockID);
 
@@ -681,7 +674,7 @@ void MainWindow::removeSeq(int index)
     int parentDockID;
     SeqWidget *seqWidget = engine->seqWidget(index);
 
-    parentDockID = seqWidget->manageBox->parentDockID;
+    parentDockID = seqWidget->parentDockID;
     QDockWidget *dockWidget = engine->moduleWindow(parentDockID);
     globStore->removeModule(parentDockID);
 
@@ -1530,23 +1523,6 @@ void MainWindow::ftb_update_orientation(Qt::Orientation orient)
     }
 }
 
-void MainWindow::skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
-
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
-
 #ifdef NSM
 int MainWindow::cb_nsm_open(const char *name, const char *display_name, const char *client_id, char **out_msg, void *userdata)
 {
