@@ -2,9 +2,8 @@
  * @file midiarp.cpp
  * @brief Implements the MidiArp MIDI worker class for the Arpeggiator Module.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -83,29 +82,16 @@ MidiArp::MidiArp()
         qWarning("seq: %d (after update)", rdata->foo);
     }
 */
-    for (int l1 = 0; l1 < 2; l1++) {
-        rangeIn[l1] = (l1) ? 127 : 0;
-        indexIn[l1] = (l1) ? 127 : 0;
-    }
-    chIn = 0;
-    portOut = 0;
-    channelOut = 0;
     noteBufPtr = 0;
-    noteCount = 0;
     releaseNoteCount = 0;
-    triggerMode = 0;
-    restartByKbd = false;
-    trigByKbd = false;
-    trigLegato = false;
-    gotKbdTrig = false;
-    restartFlag = false;
     stepWidth = 1.0;     // stepWidth relative to global queue stepWidth
     minStepWidth = 1.0;
     maxOctave = 0;
     minOctave = 0;
     
     octMode = 0;
-    octRange = 1;
+    octLow = 0;
+    octHigh = 0;
     octOfs = 0;
     octIncr = 0;
 
@@ -119,7 +105,6 @@ MidiArp::MidiArp()
     patternLen = 0;
     semitone = 0;
     currentNoteTick = 0;
-    nextTick = 0;
     patternMaxIndex = 0;
     noteOfs = 0;
     arpTick = 0;
@@ -130,16 +115,8 @@ MidiArp::MidiArp()
     randomTickAmp = 0;
     randomVelocityAmp = 0;
     randomLengthAmp = 0;
-    grooveTick = 0;
-    newGrooveTick = 0;
     hasNewNotes = false;
-    grooveVelocity = 0;
-    grooveLength = 0;
     repeatPatternThroughChord = 1;
-    isMuted = false;
-    isMutedDefer = false;
-    deferChanges = false;
-    parChangesPending = false;
     attack_time = 0.0;
     release_time = 0.0;
     sustain = false;
@@ -153,26 +130,12 @@ MidiArp::MidiArp()
 
     returnNote.resize(128);
     returnVelocity.resize(128);
-
-    needsGUIUpdate = false;
-}
-
-MidiArp::~MidiArp(){
-}
-
-void MidiArp::setMuted(bool on)
-{
-    isMutedDefer = on;
-    if (deferChanges) {
-        parChangesPending = true;
-    }
-    else isMuted = on;
-    needsGUIUpdate = false;
 }
 
 bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
 {
-    int bufPtr, index;
+    int bufPtr = 0;
+    int index = 0;
 
     if (inEv.channel != chIn) return(true);
     if ((inEv.type == EV_CONTROLLER) && (inEv.data == CT_FOOTSW)) {
@@ -185,13 +148,10 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         || ((inEv.value < rangeIn[0]) || (inEv.value > rangeIn[1]))) {
         return(true);
     }
-    
-    // modify buffer that is not accessed by arpeggio output
-    bufPtr = (noteBufPtr) ? 0 : 1;
 
     if (inEv.value) {
         // This is a NOTE ON event
-
+        
         if (!getPressedNoteCount() || trigLegato) {
             purgeLatchBuffer();
             if (restartByKbd) restartFlag = true;
@@ -199,11 +159,12 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
             if (trigByKbd && release_time > 0) {
                 for (int l1 = 0; l1 < noteCount; l1++) {
                     if (notes[bufPtr][3][l1])
-                        removeNote(&notes[bufPtr][0][l1], -1, 0);
-                        releaseNoteCount--;
+                        removeNote(&notes[noteBufPtr][0][l1], -1, 0);
                 }
             }
         }
+        // modify buffer that is not accessed by arpeggio output
+        bufPtr = (noteBufPtr) ? 0 : 1;
 
         if (!noteCount || (inEv.data > notes[bufPtr][0][noteCount - 1]))
             index = noteCount;
@@ -226,7 +187,7 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
 
         if ((trigByKbd
-                && ((noteCount - latchBufferCount - releaseNoteCount) == 1))
+                && (getPressedNoteCount() == 1))
                     || trigLegato) {
             initArpTick(tick + trigDelayTicks);
             gotKbdTrig = true;
@@ -234,6 +195,8 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
     }
     else {
         // This is a NOTE OFF event
+        // modify buffer that is not accessed by arpeggio output
+        bufPtr = (noteBufPtr) ? 0 : 1;
 
         if (!noteCount) {
             return(false);
@@ -270,6 +233,7 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         }
         else tagAsReleased(inEv.data, tick, bufPtr);
     }
+    
     copyNoteBuffer();
     return(false);
 }
@@ -289,6 +253,7 @@ void MidiArp::removeNote(int *noteptr, int tick, int keep_rel)
         if (note == notes[bufPtr][0][noteCount - 1]) {
             // note is on top of buffer: only decrement noteCount
             noteCount--;
+            if (tick == -1) releaseNoteCount--;
             if ((repeatPatternThroughChord == 2) && (noteOfs)) noteOfs--;
         }
         else {
@@ -305,6 +270,7 @@ void MidiArp::removeNote(int *noteptr, int tick, int keep_rel)
 
             if (note == notes[bufPtr][0][index]) {
                 deleteNoteAt(index, bufPtr);
+                if (tick == -1) releaseNoteCount--;
                 for (int l2 = index; l2 < noteCount; l2++) {
                     old_attackfn[l2] = old_attackfn[l2 + 1];
                 }
@@ -357,7 +323,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
     QChar c;
     int l1, tmpIndex[MAXCHORD], chordIndex, grooveTmp;
     int current_octave = 0;
-    int outOfRange = 0;
+    bool outOfRange = false;
     bool gotCC, pause;
     double attackfn, releasefn;
 
@@ -448,7 +414,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
         noteIndex[l1] = (noteCount) ? tmpIndex[l1] % noteCount : 0;
         note[l1] = clip(notes[noteBufPtr][0][noteIndex[l1]] + current_octave * 12
                 + chordSemitone[l1], 0, 127, &outOfRange);
-        if (outOfRange != 0) checkOctaveAtEdge(false);
+        if (outOfRange) checkOctaveAtEdge(false);
 
         grooveTmp = (grooveIndex % 2) ? -grooveVelocity : grooveVelocity;
 
@@ -478,9 +444,8 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
                 * vel * (1.0 + 0.005 * (double)(randomVelocity + grooveTmp))
                 * releasefn * attackfn, 0, 127, &outOfRange);
 
-        if ((notes[noteBufPtr][3][noteIndex[l1]]) && (!velocity[l1])) {
+        if ((release_time > 0.) && (notes[noteBufPtr][3][noteIndex[l1]]) && (!velocity[l1])) {
             removeNote(&notes[noteBufPtr][0][noteIndex[l1]], -1, 0);
-            releaseNoteCount--;
         }
         else {
             l1++;
@@ -523,28 +488,41 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
 void MidiArp::checkOctaveAtEdge(bool reset)
 {
     if (!octMode) return;
-    
-    if (reset) {
+    if (!octHigh && !octLow) {
         octOfs = 0;
-        if (octMode == 2) octIncr = -1; else octIncr = 1;
         return;
     }
-    if (octOfs > octRange) {
+    
+    if (reset) {
+        octOfs = octLow;
+        if (octMode == 2) {
+            octOfs = octHigh;
+            octIncr = -1;
+        }
+        else {
+            octOfs = octLow;
+            octIncr = 1;
+        }
+        return;
+    }
+    if (octOfs > octHigh) {
         if (octMode == 3){
             octIncr = - octIncr;
             octOfs--;
+            octOfs--;
         }
         else {
-            octOfs = -octRange;
+            octOfs = octLow;
         }
     }
-    if (octOfs < -octRange) {
+    if (octOfs < octLow) {
         if (octMode == 3) {
             octIncr = - octIncr;
             octOfs++;
+            octOfs++;
         }
         else {
-            octOfs = octRange;
+            octOfs = octHigh;
         }
     }
 }
@@ -762,21 +740,6 @@ void MidiArp::updatePattern(const QString& p_pattern)
     nPoints = npoints;
 }
 
-int MidiArp::clip(int value, int min, int max, int *outOfRange)
-{
-    int tmp = value;
-
-    *outOfRange = false;
-    if (tmp > max) {
-        tmp = max;
-        *outOfRange = 1;
-    } else if (tmp < min) {
-        tmp = min;
-        *outOfRange = -1;
-    }
-    return(tmp);
-}
-
 void MidiArp::newRandomValues()
 {
     randomTick = (double)randomTickAmp * (0.5 - (double)random()
@@ -836,14 +799,6 @@ void MidiArp::updateReleaseTime(int val)
     release_time = (double)val;
 }
 
-void MidiArp::updateTriggerMode(int val)
-{
-    triggerMode = val;
-    trigByKbd = ((val == 2) || (val == 4));
-    restartByKbd = (val > 0);
-    trigLegato = (val > 2);
-}
-
 void MidiArp::clearNoteBuffer()
 {
     noteCount = 0;
@@ -890,14 +845,6 @@ void MidiArp::purgeLatchBuffer()
     latchBufferCount = 0;
 }
 
-void MidiArp::newGrooveValues(int p_grooveTick, int p_grooveVelocity,
-        int p_grooveLength)
-{
-    newGrooveTick = p_grooveTick;
-    grooveVelocity = p_grooveVelocity;
-    grooveLength = p_grooveLength;
-}
-
 void MidiArp::applyPendingParChanges()
 {
     if (!parChangesPending) return;
