@@ -2,9 +2,8 @@
  * @file midiarp_lv2.cpp
  * @brief Implements an LV2 plugin inheriting from MidiArp
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -322,8 +321,12 @@ void MidiArpLV2::updateParams()
     if (octMode != *val[OCTAVE_MODE]) {
         updateOctaveMode(*val[OCTAVE_MODE]);
     }
+    if (latch_mode != (bool)*val[LATCH_MODE]) {
+        setLatchMode((bool)*val[LATCH_MODE]);
+    }
     
-    octRange     =   (int)*val[OCTAVE_RANGE];
+    octLow     =   (int)*val[OCTAVE_LOW];
+    octHigh     =   (int)*val[OCTAVE_HIGH];
 
 
     if (deferChanges != ((bool)*val[DEFER])) deferChanges = ((bool)*val[DEFER]);
@@ -388,7 +391,7 @@ void MidiArpLV2::sendPattern(const QString & p)
     /* prepare forge buffer and initialize atom-sequence */
     LV2_Atom_Forge_Frame frame;
     lv2_atom_forge_frame_time(&forge, 0);
-    lv2_atom_forge_blank(&forge, &frame, 1, uris->pattern_string);
+    lv2_atom_forge_object(&forge, &frame, 1, uris->pattern_string);
 
     /* forge container object of type 'pattern_string' */
     lv2_atom_forge_property_head(&forge, uris->pattern_string, 0);
