@@ -2,9 +2,8 @@
  * @file midiarp_lv2.h
  * @brief Headers for the MidiArp LV2 plugin class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -55,8 +54,8 @@ public:
             MUTE = 10,
             LATCH_MODE = 11,
             OCTAVE_MODE = 12,
-            OCTAVE_RANGE = 13,
-            MOUSEPRESSED = 14,
+            OCTAVE_LOW = 13,
+            OCTAVE_HIGH = 14,
             INDEX_IN1 = 15,
             INDEX_IN2 = 16,
             RANGE_IN1 = 17,
