@@ -2,9 +2,8 @@
  * @file midicontrol.cpp
  * @brief Implements the MidiControl QWidget class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -127,7 +126,7 @@ void MidiControl::removeMidiCC(int controlID, int ccnumber, int channel)
 
 void MidiControl::midiLearn(int controlID)
 {
-    emit setMidiLearn(parentDockID, ID, controlID);
+    emit setMidiLearn(parentDockID, controlID);
     qWarning("Requesting Midi Learn for %s", qPrintable(names[controlID]));
     cancelMidiLearnAction->setEnabled(true);
 }
@@ -139,7 +138,7 @@ void MidiControl::midiForget(int controlID)
 
 void MidiControl::midiLearnCancel()
 {
-    emit setMidiLearn(parentDockID, ID, -1);
+    emit setMidiLearn(parentDockID, -1);
     qWarning("Cancelling Midi Learn request");
     cancelMidiLearnAction->setEnabled(false);
 }
@@ -219,20 +218,3 @@ void MidiControl::setCcList(const QVector<MidiCC> &p_ccList)
 {
     ccList = p_ccList;
 }
-
-void MidiControl::skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
-
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
