@@ -2,9 +2,8 @@
  * @file midicontrol.h
  * @brief Member definitions for the MidiControl QWidget class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -109,15 +108,13 @@ class MidiControl : public QWidget
 * @param count Internal identifier of the controllable QWidget
 */
     void addMidiLearnMenu(const QString &name, QWidget *widget, int count = 0);
-    void skipXmlElement(QXmlStreamReader& xml);
 
   signals:
 /*! @brief Connected to Engine::setMidiLearn() to listen for incoming events.
 *  @param parentdockid parentDockID of the module requesting MIDI learn
-*  @param id ID of the module recequesting MIDI learn
 *  @param controlID ID of the GUI element to be assigned to the controller
 */
-    void setMidiLearn(int parentdockid, int id, int controlID);
+    void setMidiLearn(int parentdockid, int controlID);
 
   public slots:
 /*!
