@@ -2,9 +2,8 @@
  * @file midilfo.cpp
  * @brief Implements the MidiLfo MIDI worker class for the LFO Module.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -28,18 +27,6 @@
 
 MidiLfo::MidiLfo()
 {
-    enableNoteOff = false;
-    trigByKbd = false;
-    gotKbdTrig = false;
-    restartByKbd = false;
-    trigLegato = false;
-    enableLoop = true;
-    curLoopMode = 0;
-    seqFinished = false;
-    restartFlag = false;
-    noteCount = 0;
-
-    queueTempo = 100.0;
     amp = 64;
     offs = 0;
     freq = 8;
@@ -48,22 +35,9 @@ MidiLfo::MidiLfo()
     nPoints = 16;
     maxNPoints = 16;
     old_res = 0;
-    ccnumber = 74;
-    portOut = 0;
-    channelOut = 0;
-    chIn = 0;
-    ccnumberIn = 74;
     waveFormIndex = 0;
-    isMuted = false;
-    isMutedDefer = false;
-    deferChanges = false;
-    parChangesPending = false;
     recordMode = false;
     isRecording = false;
-    reverse = false;
-    pingpong = false;
-    backward = false;
-    reflect = false;
     recValue = 0;
     int l1 = 0;
     int lt = 0;
@@ -90,28 +64,8 @@ MidiLfo::MidiLfo()
     lastMouseY = 0;
     frameptr = 0;
     frameSize = 1;
-    nextTick = 0;
-    grooveTick = 0;
-    newGrooveTick = 0;
-    grooveVelocity = 0;
-    grooveLength = 0;
 
     lastMute = false;
-    dataChanged = false;
-    needsGUIUpdate = false;
-}
-
-MidiLfo::~MidiLfo(){
-}
-
-void MidiLfo::setMuted(bool on)
-{
-    isMutedDefer = on;
-    if (deferChanges) {
-        parChangesPending = true;
-    }
-    else isMuted = on;
-    needsGUIUpdate = false;
 }
 
 void MidiLfo::getNextFrame(int tick)
@@ -324,21 +278,6 @@ void MidiLfo::getData(QVector<Sample> *p_data)
     *p_data = data;
 }
 
-int MidiLfo::clip(int value, int min, int max, bool *outOfRange)
-{
-    int tmp = value;
-
-    *outOfRange = false;
-    if (tmp > max) {
-        tmp = max;
-        *outOfRange = true;
-    } else if (tmp < min) {
-        tmp = min;
-        *outOfRange = true;
-    }
-    return(tmp);
-}
-
 void MidiLfo::updateWaveForm(int val)
 {
     waveFormIndex = val;
@@ -385,11 +324,6 @@ void MidiLfo::updateLoop(int val)
     }
 }
 
-void MidiLfo::updateQueueTempo(int val)
-{
-    queueTempo = (double)val;
-}
-
 int MidiLfo::setCustomWavePoint(double mouseX, double mouseY, bool newpt)
 {
     Sample sample;
@@ -419,6 +353,8 @@ int MidiLfo::setCustomWavePoint(double mouseX, double mouseY, bool newpt)
         sample.value = lastMouseY;
         customWave.replace(lastMouseLoc, sample);
     } while (lastMouseLoc != loc);
+
+    newCustomOffset();
     return (loc);
 }
 
@@ -433,12 +369,9 @@ int MidiLfo::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
         else if (pressed == 0)
             ix = setMutePoint(mouseX, lastMute);
     }
-    else if (pressed != 2) {
-        if (waveFormIndex < 5) {
-            copyToCustom();
-        }
+    else if ((pressed != 2) && (buttons == 1)) {
+        if (waveFormIndex < 5) copyToCustom();
         ix = setCustomWavePoint(mouseX, mouseY, pressed);
-        newCustomOffset();
     }
     dataChanged = true;
     return (ix);
@@ -488,9 +421,41 @@ void MidiLfo::newCustomOffset()
         if (value < min) min = value;
     }
     cwmin = min;
+#ifdef APPBUILD
+    offs = min;
+#endif
 }
 
-void MidiLfo::updateCustomWaveOffset(int cwoffs)
+void MidiLfo::flipWaveVertical()
+{
+    Sample sample;
+    int min = 127;
+    int max = 0;
+    int value, l1;
+    const int npoints = res * size;
+    
+    if (waveFormIndex < 5) {
+        copyToCustom();
+    }
+    
+    for (l1 = 0; l1 < npoints; l1++) {
+        value = customWave.at(l1).value;
+        if (value < min) min = value;
+        if (value > max) max = value;
+    }
+
+    for (l1 = 0; l1 < npoints; l1++) {
+        sample = customWave.at(l1);
+        sample.value = min + max - sample.value;
+        customWave.replace(l1, sample);
+    }
+    cwmin = min;
+#ifdef APPBUILD
+    offs = min;
+#endif
+}
+
+void MidiLfo::updateCustomWaveOffset(int o)
 {
     Sample sample;
     const int count = res * size;
@@ -498,7 +463,7 @@ void MidiLfo::updateCustomWaveOffset(int cwoffs)
     bool cl = false;
 
     while ((!cl) && (l1 < count)) {
-        sample.value = clip(customWave.at(l1).value + cwoffs - cwmin,
+        sample.value = clip(customWave.at(l1).value + o - cwmin,
                             0, 127, &cl);
         l1++;
         }
@@ -507,10 +472,10 @@ void MidiLfo::updateCustomWaveOffset(int cwoffs)
 
     for (l1 = 0; l1 < count; l1++) {
         sample = customWave.at(l1);
-        sample.value += cwoffs - cwmin;
+        sample.value += o - cwmin;
         customWave.replace(l1, sample);
     }
-    cwmin = cwoffs;
+    cwmin = o;
 }
 
 bool MidiLfo::toggleMutePoint(double mouseX)
@@ -590,6 +555,11 @@ bool MidiLfo::handleEvent(MidiEvent inEv, int tick)
         return (false);
     }
     if (inEv.type != EV_NOTEON) return (true);
+    
+    if (((inEv.data < indexIn[0]) || (inEv.data > indexIn[1]))
+        || ((inEv.value < rangeIn[0]) || (inEv.value > rangeIn[1]))) {
+        return(true);
+    }
 
     if (inEv.value) {
         /*This is a NOTE ON event*/
@@ -609,16 +579,6 @@ bool MidiLfo::handleEvent(MidiEvent inEv, int tick)
     return(false);
 }
 
-void MidiLfo::newGrooveValues(int p_grooveTick, int p_grooveVelocity,
-        int p_grooveLength)
-{
-    // grooveTick is only updated on pair steps to keep quantization
-    // newGrooveTick stores the GUI value temporarily
-    newGrooveTick = p_grooveTick;
-    grooveVelocity = p_grooveVelocity;
-    grooveLength = p_grooveLength;
-}
-
 void MidiLfo::applyPendingParChanges()
 {
     if (!parChangesPending) return;
