@@ -2,9 +2,8 @@
  * @file midilfo_lv2.cpp
  * @brief Implements an LV2 plugin inheriting from MidiLfo
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -193,6 +192,13 @@ void MidiLfoLV2::run ( uint32_t nframes )
                     /* UI was closed */
                     ui_up = false;
                 }
+                else if (obj->body.otype == uris->flip_wave) {
+                    /* LFO wave was vertically flipped */
+                    flipWaveVertical();
+                    getData(&data);
+                    updateWaveForm(5);
+                    dataChanged = true;
+                }
             }
             // MIDI Input
             else if (event && event->body.type == MidiEventID) {
@@ -324,7 +330,10 @@ void MidiLfoLV2::updateParams()
         setRecordMode((bool)*val[RECORD]);
     }
     if (deferChanges != ((bool)*val[DEFER])) deferChanges = ((bool)*val[DEFER]);
-    if (isMuted != (bool)*val[MUTE] && !parChangesPending) setMuted((bool)(*val[MUTE]));
+    if (isMuted != (bool)*val[MUTE] && !parChangesPending) {
+        setMuted((bool)(*val[MUTE]));
+        changed = true;
+    }
 
     ccnumber =       (int)*val[CC_OUT];
     ccnumberIn =     (int)*val[CC_IN];
@@ -335,6 +344,10 @@ void MidiLfoLV2::updateParams()
 
     channelOut =      (int)*val[CH_OUT];
     chIn =            (int)*val[CH_IN];
+    indexIn[0]   =   (int)*val[INDEX_IN1];
+    indexIn[1]   =   (int)*val[INDEX_IN2];
+    rangeIn[0]   =   (int)*val[RANGE_IN1];
+    rangeIn[1]   =   (int)*val[RANGE_IN2];
 
     if (internalTempo != *val[TEMPO]) {
         internalTempo = *val[TEMPO];
@@ -391,7 +404,7 @@ void MidiLfoLV2::sendWave()
     /* forge container object of type 'hex_customwave' */
     LV2_Atom_Forge_Frame lv2frame;
     lv2_atom_forge_frame_time(&forge, 0);
-    lv2_atom_forge_blank(&forge, &lv2frame, 1, uris->hex_customwave);
+    lv2_atom_forge_object(&forge, &lv2frame, 1, uris->hex_customwave);
 
     /* Send customWave to UI */
     lv2_atom_forge_property_head(&forge, uris->hex_customwave, 0);
