@@ -2,9 +2,8 @@
  * @file midiseq.cpp
  * @brief Implements the MidiSeq MIDI worker class for the Seq Module.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -28,31 +27,14 @@
 
 MidiSeq::MidiSeq()
 {
-    enableNoteIn = true;
-    enableNoteOff = false;
-    enableVelIn = true;
     recordMode = false;
-    trigByKbd = false;
-    restartByKbd = false;
-    trigLegato = false;
     enableLoop = true;
-    gotKbdTrig = false;
     currentRecStep = 0;
-    seqFinished = false;
-    reverse = false;
-    pingpong = false;
-    backward = false;
-    reflect = false;
-    restartFlag = false;
-    curLoopMode = 0;
-    noteCount = 0;
     loopMarker = 0;
 
     nOctaves = 4;
     baseOctave = 3;
 
-    chIn = 0;
-    queueTempo = 100.0;
     vel = 0;
     velDefer = 0;
     transp = 0;
@@ -61,23 +43,10 @@ MidiSeq::MidiSeq()
     res = 4;
     nPoints = 16;
     maxNPoints = 16;
-    notelength = 60;
-    notelengthDefer = 60;
-    portOut = 0;
-    channelOut = 0;
+    notelength = 180;
+    notelengthDefer = 180;
     currentIndex = 0;
-    nextTick = 0;
-    grooveTick = 0;
-    newGrooveTick = 0;
-    grooveVelocity = 0;
-    grooveLength = 0;
-    isMuted = false;
-    isMutedDefer = false;
-    deferChanges = false;
-    parChangesPending = false;
     lastMute = false;
-    dataChanged = false;
-    needsGUIUpdate = false;
 
     int lt = 0;
     int l1 = 0;
@@ -95,20 +64,6 @@ MidiSeq::MidiSeq()
     muteMask.fill(false, 2048);
 }
 
-MidiSeq::~MidiSeq(){
-}
-
-void MidiSeq::setMuted(bool on)
-{
-    isMutedDefer = on;
-    if (deferChanges) {
-        parChangesPending = true;
-    }
-    else isMuted = on;
-
-    needsGUIUpdate = false;
-}
-
 bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
 {
     if (inEv.type != EV_NOTEON) return(true);
@@ -121,6 +76,10 @@ bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
             recordNote(inEv.data);
             return(false);
         }
+        if (((inEv.data < indexIn[0]) || (inEv.data > indexIn[1]))
+            || ((inEv.value < rangeIn[0]) || (inEv.value > rangeIn[1]))) {
+            return(true);
+        }
         if (enableNoteIn) {
             updateTranspose(inEv.data - 60);
             needsGUIUpdate = true;
@@ -267,21 +226,6 @@ void MidiSeq::getData(QVector<Sample> *p_data)
     *p_data = data;
 }
 
-int MidiSeq::clip(int value, int min, int max, bool *outOfRange)
-{
-    int tmp = value;
-
-    *outOfRange = false;
-    if (tmp > max) {
-        tmp = max;
-        *outOfRange = true;
-    } else if (tmp < min) {
-        tmp = min;
-        *outOfRange = true;
-    }
-    return(tmp);
-}
-
 void MidiSeq::updateResolution(int val)
 {
     res = val;
@@ -341,11 +285,6 @@ void MidiSeq::recordNote(int val)
         dataChanged = true;
 }
 
-void MidiSeq::updateQueueTempo(int val)
-{
-    queueTempo = (double)val;
-}
-
 int MidiSeq::setCustomWavePoint(double mouseX, double mouseY)
 {
     currentRecStep = mouseX * res * size;
@@ -398,6 +337,31 @@ void MidiSeq::setLoopMarker(int ix)
     else nPoints = abs(loopMarker);
 }
 
+void MidiSeq::updateDispVert(int mode)
+{
+    switch (mode) {
+        case 0:
+            nOctaves = 4;
+            baseOctave = 3;
+        break;
+        case 1:
+            nOctaves = 2;
+            baseOctave = 5;
+        break;
+        case 2:
+            nOctaves = 2;
+            baseOctave = 4;
+        break;
+        case 3:
+            nOctaves = 2;
+            baseOctave = 3;
+        break;
+        default:
+            nOctaves = 4;
+            baseOctave = 3;
+    }
+}
+
 void MidiSeq::setRecordMode(int on)
 {
     recordMode = on;
@@ -486,16 +450,6 @@ void MidiSeq::setCurrentIndex(int ix)
     }
 }
 
-void MidiSeq::newGrooveValues(int p_grooveTick, int p_grooveVelocity,
-        int p_grooveLength)
-{
-    // grooveTick is only updated on pair steps to keep quantization
-    // newGrooveTick stores the GUI value temporarily
-    newGrooveTick = p_grooveTick;
-    grooveVelocity = p_grooveVelocity;
-    grooveLength = p_grooveLength;
-}
-
 void MidiSeq::applyPendingParChanges()
 {
     if (!parChangesPending) return;
