@@ -2,9 +2,8 @@
  * @file midiseq_lv2.cpp
  * @brief Implements an LV2 plugin inheriting from MidiSeq
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -44,6 +43,7 @@ MidiSeqLV2::MidiSeqLV2 (
     tempo = 120.0f;
     internalTempo = 120.0f;
     lastMouseIndex = 0;
+    dispVertIndex = 0;
 
     transportBpm = 120.0f;
     transportFramesDelta = 0;
@@ -293,6 +293,12 @@ void MidiSeqLV2::updateParams()
         changed = true;
         setLoopMarker((int)*val[LOOPMARKER]);
     }
+    
+    if (dispVertIndex != (int)*val[DISPLAY_ZOOM]) {
+        changed = true;
+        dispVertIndex = (int)*val[DISPLAY_ZOOM];
+        updateDispVert(dispVertIndex);
+    }
 
     if (mouseXCur != *val[MOUSEX] || mouseYCur != *val[MOUSEY]
                 || mouseEvCur != *val[MOUSEPRESSED]) {
@@ -360,6 +366,10 @@ void MidiSeqLV2::updateParams()
 
     channelOut =      (int)*val[CH_OUT];
     chIn =            (int)*val[CH_IN];
+    indexIn[0]   =   (int)*val[INDEX_IN1];
+    indexIn[1]   =   (int)*val[INDEX_IN2];
+    rangeIn[0]   =   (int)*val[RANGE_IN1];
+    rangeIn[1]   =   (int)*val[RANGE_IN2];
 
     if (internalTempo != *val[TEMPO]) {
         internalTempo = *val[TEMPO];
@@ -414,7 +424,7 @@ void MidiSeqLV2::sendWave()
     /* forge container object of type 'hex_customwave' */
     LV2_Atom_Forge_Frame frame;
     lv2_atom_forge_frame_time(&forge, 0);
-    lv2_atom_forge_blank(&forge, &frame, 1, uris->hex_customwave);
+    lv2_atom_forge_object(&forge, &frame, 1, uris->hex_customwave);
 
     /* Send customWave to UI */
     lv2_atom_forge_property_head(&forge, uris->hex_customwave, 0);
