@@ -2,9 +2,8 @@
  * @file parstore.cpp
  * @brief Implements the ParStore class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -29,11 +28,10 @@
 #include "pixmaps/filesave.xpm"
 
 ParStore::ParStore(GlobStore *p_globStore, const QString &name,
-            QAction *p_muteOutAction,
-            QAction *p_deferChangesAction,
-            QWidget* parent):
-                QWidget(parent), globStore(p_globStore)
+            QAction *p_muteOutAction, QAction *p_deferChangesAction,
+            QWidget *p_parent): globStore(p_globStore)
 {
+    setParent(p_parent);
     // when temp.empty is true, restoring from that set is ignored
     temp.empty = false;
     temp.muteOut = false;
@@ -57,12 +55,12 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     temp.notelen = 0;
     temp.vel = 0;
     temp.transp = 0;
-    temp.dispVertical = 0;
+    temp.dispVertIndex = 0;
     /* Arp Modules */
     temp.indexIn0 = 0;
-    temp.indexIn1 = 0;
+    temp.indexIn1 = 127;
     temp.rangeIn0 = 0;
-    temp.rangeIn1 = 0;
+    temp.rangeIn1 = 127;
     temp.attack = 0;
     temp.release = 0;
     temp.repeatMode = 0;
@@ -72,21 +70,21 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     temp.pattern = "";
     list.clear();
 
-    ndc = new Indicator(14, name.at(0), this);
+    ndc = new Indicator(14, name.at(0));
 
-    topButton = new QToolButton(this);
+    topButton = new QToolButton;
     topButton->setFont(QFont("Helvetica", 8));
     topButton->setText(name);
     topButton->setMinimumSize(QSize(75, 10));
 
     muteOutAction = p_muteOutAction;
-    muteOut = new QToolButton(this);
+    muteOut = new QToolButton;
     muteOut->setDefaultAction(muteOutAction);
     muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(10, 10));
 
     deferChangesAction = p_deferChangesAction;
-    deferChanges = new QToolButton(this);
+    deferChanges = new QToolButton;
     deferChanges->setDefaultAction(deferChangesAction);
     deferChanges->setFont(QFont("Helvetica", 8));
     deferChanges->setMinimumSize(QSize(10, 10));
@@ -104,7 +102,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     controlLayout->setMargin(0);
     controlLayout->setSpacing(0);
 
-    QWidget *indicatorBox = new QWidget(this);
+    QWidget *indicatorBox = new QWidget;
     QHBoxLayout *indicatorLayout = new QHBoxLayout;
     indicatorBox->setMinimumHeight(20);
     indicatorBox->setMinimumWidth(25);
@@ -113,7 +111,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     indicatorLayout->setSpacing(1);
     indicatorBox->setLayout(indicatorLayout);
 
-    QFrame *topRow = new QFrame(this);
+    QFrame *topRow = new QFrame;
     QHBoxLayout *topRowLayout = new QHBoxLayout;
     topRowLayout->addWidget(indicatorBox);
     topRowLayout->addLayout(controlLayout);
@@ -123,7 +121,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     topRow->setFrameStyle(QFrame::StyledPanel);
     topRow->setLayout(topRowLayout);
 
-    QVBoxLayout *buttonLayout = new QVBoxLayout();
+    QVBoxLayout *buttonLayout = new QVBoxLayout;
     buttonLayout->addWidget(topRow);
 
     locContextMenu = new QMenu(this);
@@ -183,10 +181,6 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     needsGUIUpdate = false;
 }
 
-ParStore::~ParStore()
-{
-}
-
 void ParStore::writeData(QXmlStreamWriter& xml)
 {
     int l1;
@@ -214,7 +208,7 @@ void ParStore::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("loopMarker", QString::number(list.at(ix).loopMarker));
             xml.writeTextElement("notelen", QString::number(list.at(ix).notelen));
             xml.writeTextElement("vel", QString::number(list.at(ix).vel));
-            xml.writeTextElement("dispVertical", QString::number(list.at(ix).dispVertical));
+            xml.writeTextElement("dispVertical", QString::number(list.at(ix).dispVertIndex));
             xml.writeTextElement("transp", QString::number(list.at(ix).transp));
             xml.writeTextElement("indexIn0", QString::number(list.at(ix).indexIn0));
             xml.writeTextElement("indexIn1", QString::number(list.at(ix).indexIn1));
@@ -303,7 +297,7 @@ void ParStore::readData(QXmlStreamReader& xml)
                 else if (xml.name() == "vel")
                     temp.vel = xml.readElementText().toInt();
                 else if (xml.name() == "dispVertical")
-                    temp.dispVertical = xml.readElementText().toInt();
+                    temp.dispVertIndex = xml.readElementText().toInt();
                 else if (xml.name() == "transp")
                     temp.transp = xml.readElementText().toInt();
                 else if (xml.name() == "notelen")
@@ -382,6 +376,10 @@ void ParStore::readData(QXmlStreamReader& xml)
                 }
                 else skipXmlElement(xml);
             }
+            //For compatibility with files stored before all modules got
+            //Note filters:
+            if (!(temp.indexIn0 + temp.indexIn1)) temp.indexIn1 = 127;
+            if (!(temp.rangeIn0 + temp.rangeIn1)) temp.rangeIn1 = 127;
             tempToList(ix);
             updateRunOnce(ix, tmpjumpto);
             onlyPatternList.replace(ix, tmponlypattern);
@@ -416,8 +414,7 @@ void ParStore::removeLocation(int ix)
     if (ix == -1) ix = list.count() - 1;
 
     list.removeAt(ix);
-    QWidget *button = new QWidget(this);
-    button = layout()->itemAt(0)->layout()->takeAt(ix + 1)->widget();
+    QWidget *button = layout()->itemAt(0)->layout()->takeAt(ix + 1)->widget();
     QAction *action = jumpToIndexMenu->actions().at(ix + 3);
     delete button;
     delete action;
@@ -602,20 +599,3 @@ void ParStore::updateOnlyPattern(bool on)
 {
     onlyPatternList.replace(sender()->property("index").toInt() - 1, on);
 }
-
-void ParStore::skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
-
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
