@@ -2,9 +2,8 @@
  * @file parstore.h
  * @brief Member definitions for the ParStore class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -40,6 +39,16 @@
 #include "main.h"
 
 
+/*!
+ * ParStore holds module parameter fields in its ParStore::list. These parameter
+ * fields can be read by the modules, which have a pointer to ParStore. ParStore
+ * also creates storage location GUI handling for each module. Each list entry
+ * is represented by a StorageButton and its associated context menu. GUI elements
+ * are dynamically added to and removed from the GlobStore Widget. ParStore is 
+ * midi controllable and it can save all field lists to disk. 
+
+ * @brief Manages a list of module parameter fields and GUI elements
+ */
 class ParStore : public QWidget
 {
   Q_OBJECT
@@ -48,8 +57,7 @@ class ParStore : public QWidget
     ParStore(GlobStore *p_globStore, const QString &name = "",
                 QAction* p_muteOutAction = 0,
                 QAction* p_deferChangesAction = 0,
-                QWidget* parent = 0);
-    ~ParStore();
+                QWidget *parent = 0);
     GlobStore *globStore;
     QToolButton *topButton;
     QAction *muteOutAction;
@@ -95,7 +103,7 @@ class ParStore : public QWidget
         int notelen;
         int vel;
         int transp;
-        int dispVertical;
+        int dispVertIndex;
         /* Arp Modules */
         int indexIn0;
         int indexIn1;
@@ -110,11 +118,11 @@ class ParStore : public QWidget
         QString pattern;
     };
     TempStore temp; /**< Structure to which all module parameters are copied
-                        * before being appended to the TempStore::list*/
-    QList<TempStore> list; /**< List of TempStore::temp structures for
+                        * before being appended to the ParStore::list*/
+    QList<TempStore> list; /**< List of TempStore structures for
                         parameter storage*/
 
-/**< When this variable is greater than -1, ParStore::updateDisplay() will cause
+/*! When this variable is greater than -1, ParStore::updateDisplay() will cause
 * ParStore::restoreParams(restoreRequest) at pattern end
 */
     int restoreRequest;
@@ -134,9 +142,9 @@ class ParStore : public QWidget
     int dispReqIx, dispReqSelected; 
 
 /*!
-* @brief stores all module parameters to TempStore::temp and stores temp
-* in TempStore::list at index ix. If the given index is greater than the list size,
-* temp is appended to TempStore::list.
+* @brief stores all module parameters to ParStore::temp and stores temp
+* in ParStore::list at index ix. If the given index is greater than the list size,
+* temp is appended to ParStore::list.
 *
 * @param ix Index at which the parameters are stored.
 */
@@ -183,7 +191,6 @@ class ParStore : public QWidget
 * @param reverse Set to true if the parent module currently plays backward
 */
     void updateDisplay(int frame, bool reverse);
-    void skipXmlElement(QXmlStreamReader& xml);
 
   signals:
 /*!
