@@ -2,9 +2,8 @@
  * @file seqdriver.h
  * @brief Header for the SeqDriver class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -112,15 +111,15 @@ class SeqDriver : public DriverBase {
         ~SeqDriver();
         double getCurrentTime();
         void calcCurrentTick(double time); /** calculate m_current_tick based on realTime */
-        void requestTempo(double bpm); /** reimplemented over DriverBase */
-        void setTempo(double bpm); /** reimplemented over DriverBase */
-        int getClientId(); /** reimplemented over DriverBase */
+        void requestTempo(double bpm);
+        void setTempo(double bpm);
+        int getClientId();
         void run();
 
    public slots:
-        void setTransportStatus(bool run); /** is pure in DriverBase */
-        void setUseMidiClock(bool on); /** reimplemented over DriverBase */
-        void setUseJackTransport(bool on); /** reimplemented over DriverBase */
+        void setTransportStatus(bool run);
+        void setUseMidiClock(bool on);
+        void setUseJackTransport(bool on);
 };
 
 #endif
