@@ -2,9 +2,8 @@
  * @file seqscreen.cpp
  * @brief Implementation of the SeqScreen class
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -32,7 +31,7 @@
 #include "engine.h"
 
 
-SeqScreen::SeqScreen(QWidget* parent) : QWidget (parent)
+SeqScreen::SeqScreen()
 {
     setPalette(QPalette(QColor(0, 20, 100), QColor(0, 20, 100)));
     mouseX = 0;
@@ -50,10 +49,6 @@ SeqScreen::SeqScreen(QWidget* parent) : QWidget (parent)
     needsRedraw = false;
 }
 
-SeqScreen::~SeqScreen()
-{
-}
-
 // Paint event handler.
 void SeqScreen::paintEvent(QPaintEvent*)
 {
@@ -191,7 +186,12 @@ void SeqScreen::paintEvent(QPaintEvent*)
                             xpos + (xscale / beatRes) - pen.width(), ypos);
         }
     }
-    ypos = int((mouseY - SEQSCR_VMARG + 3)/4) * 4 + SEQSCR_VMARG - 2;
+    
+    // Helper tickline on keyboard
+    ypos = yscale - yscale * (int)((1. - ((double)mouseY - SEQSCR_VMARG)
+            / (h - 2 * SEQSCR_VMARG)) * nOctaves * 12) / nOctaves / 12
+            + SEQSCR_VMARG - 1 - pen.width() / 2;
+
     pen.setWidth(2);
     pen.setColor(QColor(50, 160, 220));
     p.setPen(pen);
@@ -288,6 +288,32 @@ void SeqScreen::updateDraw()
     update();
 }
 
+void SeqScreen::updateDispVert(int mode)
+{
+    switch (mode) {
+        case 0:
+            nOctaves = 4;
+            baseOctave = 3;
+        break;
+        case 1:
+            nOctaves = 2;
+            baseOctave = 5;
+        break;
+        case 2:
+            nOctaves = 2;
+            baseOctave = 4;
+        break;
+        case 3:
+            nOctaves = 2;
+            baseOctave = 3;
+        break;
+        default:
+            nOctaves = 4;
+            baseOctave = 3;
+    }
+    update();
+}
+
 QSize SeqScreen::sizeHint() const
 {
     return QSize(SEQSCR_MIN_W, SEQSCR_MIN_H);
