@@ -2,9 +2,8 @@
  * @file seqwidget.cpp
  * @brief Implements the SeqWidget GUI class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -37,189 +36,32 @@
 #ifdef APPBUILD
 SeqWidget::SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
     int portCount, bool compactStyle,
-    bool mutedAdd, bool inOutVisible, const QString& name, QWidget *parent):
-    QWidget(parent),
-    midiWorker(p_midiWorker),
-    globStore(p_globStore),
-    modified(false)
+    bool mutedAdd, bool inOutVisible, const QString& p_name):
+    InOutBox(p_midiWorker, p_globStore, portCount, compactStyle, inOutVisible, p_name),
+    midiWorker(p_midiWorker)
 {
-    midiControl = new MidiControl(this);
-    manageBox = new ManageBox("Seq:", true, this);
 #else
 SeqWidget::SeqWidget(
     bool compactStyle,
-    bool mutedAdd, bool inOutVisible, QWidget *parent):
-    QWidget(parent),
-    modified(false)
+    bool mutedAdd, bool inOutVisible):
+    InOutBox(compactStyle, inOutVisible, "Seq:"),
+    midiWorker(NULL)
 {
-    midiWorker = NULL;
 #endif
-    int l1;
-
-    // Input group box on right top
-    QGroupBox *inBox = new QGroupBox(tr("Input"), this);
-
-    QLabel *enableNoteInLabel = new QLabel(tr("&Note"),inBox);
-    enableNoteIn = new QCheckBox(this);
-    connect(enableNoteIn, SIGNAL(toggled(bool)), this, SLOT(updateEnableNoteIn(bool)));
-    enableNoteInLabel->setBuddy(enableNoteIn);
-    enableNoteIn->setToolTip(tr("Transpose the sequence following incoming notes"));
-
-    QLabel *enableNoteOffLabel = new QLabel(tr("&Note Off"),inBox);
-    enableNoteOff = new QCheckBox(this);
-    connect(enableNoteOff, SIGNAL(toggled(bool)), this, SLOT(updateEnableNoteOff(bool)));
-    enableNoteOffLabel->setBuddy(enableNoteOff);
-    enableNoteOff->setToolTip(tr("Stop output when Note is released"));
-
-    QLabel *enableVelInLabel = new QLabel(tr("&Velocity"),inBox);
-    enableVelIn = new QCheckBox(this);
-    connect(enableVelIn, SIGNAL(toggled(bool)), this, SLOT(updateEnableVelIn(bool)));
-    enableVelInLabel->setBuddy(enableVelIn);
-    enableVelIn->setToolTip(tr("Set sequence velocity to that of incoming notes"));
-
-    QLabel *enableRestartByKbdLabel = new QLabel(tr("&Restart"),inBox);
-    enableRestartByKbd = new QCheckBox(this);
-    connect(enableRestartByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableRestartByKbd(bool)));
-    enableRestartByKbdLabel->setBuddy(enableRestartByKbd);
-    enableRestartByKbd->setToolTip(tr("Restart sequence when a new note is received"));
-
-    QLabel *enableTrigByKbdLabel = new QLabel(tr("&Trigger"),inBox);
-    enableTrigByKbd = new QCheckBox(this);
-    connect(enableTrigByKbd, SIGNAL(toggled(bool)), this, SLOT(updateEnableTrigByKbd(bool)));
-    enableTrigByKbdLabel->setBuddy(enableTrigByKbd);
-    enableTrigByKbd->setToolTip(tr("Retrigger sequence when a new note is received"));
-
-    QLabel *enableTrigLegatoLabel = new QLabel(tr("&Legato"),inBox);
-    enableTrigLegato = new QCheckBox(this);
-    connect(enableTrigLegato, SIGNAL(toggled(bool)), this, SLOT(updateTrigLegato(bool)));
-    enableTrigLegatoLabel->setBuddy(enableTrigLegato);
-    enableTrigLegato->setToolTip(tr("Retrigger / restart upon new legato note as well"));
-
-    enableNoteIn->setChecked(true);
-    enableNoteOff->setChecked(false);
-    enableVelIn->setChecked(true);
-    enableRestartByKbd->setChecked(false);
-    enableTrigByKbd->setChecked(false);
-    enableTrigLegato->setChecked(false);
-
-    QLabel *chInLabel = new QLabel(tr("&Channel"), inBox);
-    chIn = new QComboBox(inBox);
-    for (l1 = 0; l1 < 16; l1++) chIn->addItem(QString::number(l1 + 1));
-    chInLabel->setBuddy(chIn);
-    connect(chIn, SIGNAL(activated(int)), this, SLOT(updateChIn(int)));
-
-    QGridLayout *inBoxLayout = new QGridLayout;
-
-    inBoxLayout->addWidget(enableNoteInLabel, 0, 0);
-    inBoxLayout->addWidget(enableNoteIn, 0, 1);
-    inBoxLayout->addWidget(enableNoteOffLabel, 1, 0);
-    inBoxLayout->addWidget(enableNoteOff, 1, 1);
-    inBoxLayout->addWidget(enableVelInLabel, 2, 0);
-    inBoxLayout->addWidget(enableVelIn, 2, 1);
-    inBoxLayout->addWidget(enableRestartByKbdLabel, 3, 0);
-    inBoxLayout->addWidget(enableRestartByKbd, 3, 1);
-    inBoxLayout->addWidget(enableTrigByKbdLabel, 4, 0);
-    inBoxLayout->addWidget(enableTrigByKbd, 4, 1);
-    inBoxLayout->addWidget(enableTrigLegatoLabel, 5, 0);
-    inBoxLayout->addWidget(enableTrigLegato, 5, 1);
-    inBoxLayout->addWidget(chInLabel, 6, 0);
-    inBoxLayout->addWidget(chIn, 6, 1);
-    if (compactStyle) {
-        inBoxLayout->setSpacing(1);
-        inBoxLayout->setMargin(2);
-    }
-
-    inBox->setLayout(inBoxLayout);
-
-
-    // Output group box on right bottom
-    QGroupBox *portBox = new QGroupBox(tr("Output"), this);
-
-    QLabel *channelLabel = new QLabel(tr("C&hannel"), portBox);
-    channelOut = new QComboBox(portBox);
-    channelLabel->setBuddy(channelOut);
-    for (l1 = 0; l1 < 16; l1++) channelOut->addItem(QString::number(l1 + 1));
-    connect(channelOut, SIGNAL(activated(int)), this,
-            SLOT(updateChannelOut(int)));
-
-    QGridLayout *portBoxLayout = new QGridLayout;
-
-#ifdef APPBUILD
-        QLabel *portLabel = new QLabel(tr("&Port"), portBox);
-        portOut = new QComboBox(portBox);
-        portLabel->setBuddy(portOut);
-        for (l1 = 0; l1 < portCount; l1++) portOut->addItem(QString::number(l1 + 1));
-        connect(portOut, SIGNAL(activated(int)), this, SLOT(updatePortOut(int)));
-
-        portBoxLayout->addWidget(portLabel, 0, 0);
-        portBoxLayout->addWidget(portOut, 0, 1);
-#endif
-
-    portBoxLayout->addWidget(channelLabel, 1, 0);
-    portBoxLayout->addWidget(channelOut, 1, 1);
-
-    QVBoxLayout* outputLayout = new QVBoxLayout;
-    outputLayout->addLayout(portBoxLayout);
-    if (compactStyle) {
-        outputLayout->setSpacing(1);
-        outputLayout->setMargin(2);
-    }
-
-    portBox->setLayout(outputLayout);
-
-    hideInOutBoxAction = new QAction(tr("&Show/hide in-out settings"), this);
-    QToolButton *hideInOutBoxButton = new QToolButton(this);
-    hideInOutBoxAction->setCheckable(true);
-    hideInOutBoxAction->setChecked(inOutVisible);
-    hideInOutBoxButton->setDefaultAction(hideInOutBoxAction);
-    hideInOutBoxButton->setFixedSize(10, 80);
-    hideInOutBoxButton->setArrowType (Qt::ArrowType(0));
-    connect(hideInOutBoxAction, SIGNAL(toggled(bool)), this, SLOT(setInOutBoxVisible(bool)));
-
-    QVBoxLayout *inOutBoxLayout = new QVBoxLayout;
-#ifdef APPBUILD
-    inOutBoxLayout->addWidget(manageBox);
-#endif
-    inOutBoxLayout->addWidget(inBox);
-    inOutBoxLayout->addWidget(portBox);
-    inOutBoxLayout->addStretch();
-    inOutBox = new QWidget(this);
-    inOutBox->setLayout(inOutBoxLayout);
-    inOutBox->setVisible(inOutVisible);
 
     // group box for sequence setup
-    QGroupBox *seqBox = new QGroupBox(tr("Sequence"), this);
+    QGroupBox *seqBox = new QGroupBox(tr("Sequence"));
 
-    screen = new SeqScreen(this);
+    screen = new SeqScreen;
     screen->setToolTip(
         tr("Right button to mute points, left button to draw custom wave"));
     screen->setMinimumHeight(SEQSCR_MIN_H);
     connect(screen, SIGNAL(mouseEvent(double, double, int, int)), this,
             SLOT(mouseEvent(double, double, int, int)));
 
-    cursor = new Cursor('S', this);
+    cursor = new Cursor('S');
 
-    muteOutAction = new QAction(tr("&Mute"),this);
-    muteOutAction->setCheckable(true);
-    connect(muteOutAction, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)));
-    muteOut = new QToolButton(this);
-    muteOut->setDefaultAction(muteOutAction);
-    muteOut->setFont(QFont("Helvetica", 8));
-    muteOut->setMinimumSize(QSize(35,20));
-
-#ifdef APPBUILD
-    midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
-#endif
-    deferChangesAction = new QAction("D", this);
-    deferChangesAction->setToolTip(tr("Defer mute, velocity, note length and transpose to pattern end"));
-    deferChangesAction->setCheckable(true);
-    connect(deferChangesAction, SIGNAL(toggled(bool)), this, SLOT(updateDeferChanges(bool)));
-
-    QToolButton *deferChangesButton = new QToolButton(this);
-    deferChangesButton->setDefaultAction(deferChangesAction);
-    deferChangesButton->setFixedSize(20, 20);
-
-    loopBox = new QComboBox(seqBox);
+    loopBox = new QComboBox;
     QStringList names;
     names.clear();
     names << "->_>" << " <_<-" << "->_<" << " >_<-" << "->_|" << " |_<-" << "RANDM";
@@ -232,11 +74,11 @@ SeqWidget::SeqWidget(
 #ifdef APPBUILD
     midiControl->addMidiLearnMenu("LoopMode", loopBox, 6);
 #endif
-    QLabel *recordButtonLabel = new QLabel(tr("Re&cord"), seqBox);
-    recordAction = new QAction(QPixmap(seqrecord_xpm), tr("Re&cord"), seqBox);
+    QLabel *recordButtonLabel = new QLabel(tr("Re&cord"));
+    recordAction = new QAction(QPixmap(seqrecord_xpm), tr("Re&cord"), this);
     recordAction->setToolTip(tr("Record step by step"));
     recordAction->setCheckable(true);
-    QToolButton *recordButton = new QToolButton(seqBox);
+    QToolButton *recordButton = new QToolButton;
     recordButton->setDefaultAction(recordAction);
     recordButtonLabel->setBuddy(recordButton);
     connect(recordAction, SIGNAL(toggled(bool)), this, SLOT(setRecord(bool)));
@@ -244,9 +86,8 @@ SeqWidget::SeqWidget(
     midiControl->addMidiLearnMenu("RecordToggle", recordButton, 3);
 #endif
 
-    QLabel *resBoxLabel = new QLabel(tr("&Resolution"),
-            seqBox);
-    resBox = new QComboBox(seqBox);
+    QLabel *resBoxLabel = new QLabel(tr("&Resolution"));
+    resBox = new QComboBox;
     resBoxLabel->setBuddy(resBox);
     names.clear();
     names << "1" << "2" << "4" << "8" << "16";
@@ -262,8 +103,8 @@ SeqWidget::SeqWidget(
     midiControl->addMidiLearnMenu("Resolution", resBox, 4);
 #endif
 
-    QLabel *sizeBoxLabel = new QLabel(tr("&Length"), seqBox);
-    sizeBox = new QComboBox(seqBox);
+    QLabel *sizeBoxLabel = new QLabel(tr("&Length"));
+    sizeBox = new QComboBox;
     sizeBoxLabel->setBuddy(sizeBox);
     names.clear();
     names << "1" << "2" << "3" << "4" << "5" << "6" << "7" << "8" << "16" << "32";
@@ -278,7 +119,7 @@ SeqWidget::SeqWidget(
     midiControl->addMidiLearnMenu("Size", sizeBox, 5);
 #endif
 
-    QSignalMapper *dispSignalMapper = new QSignalMapper(this);
+    dispSignalMapper = new QSignalMapper(this);
     QLabel *dispLabel[4];
     QString dispText[4] = {tr("&F"), tr("&U"), tr("&M"), tr("&L")};
     QString dispToolTip[4] = {tr("Full"), tr("Upper"), tr("Mid"), tr("Lower")};
@@ -288,8 +129,8 @@ SeqWidget::SeqWidget(
     dispBoxLayout->addWidget(new QLabel(tr("Display")));
     dispBoxLayout->addStretch(10);
     for (int l1 = 0; l1 < 4; l1++) {
-        dispLabel[l1] = new QLabel(dispText[l1],this);
-        dispVert[l1] = new QCheckBox(this);
+        dispLabel[l1] = new QLabel(dispText[l1]);
+        dispVert[l1] = new QCheckBox;
         connect(dispVert[l1], SIGNAL(toggled(bool)), dispSignalMapper, SLOT(map()));
         dispSignalMapper->setMapping(dispVert[l1], l1);
         dispVert[l1]->setAutoExclusive(true);
@@ -301,12 +142,12 @@ SeqWidget::SeqWidget(
     dispBoxLayout->addStretch();
 
     dispVert[0]->setChecked(true);
-    dispVertical = 0;
+    dispVertIndex = 0;
     connect(dispSignalMapper, SIGNAL(mapped(int)),
              this, SLOT(updateDispVert(int)));
 
     velocity = new Slider(0, 127, 1, 8, 64, Qt::Horizontal,
-            tr("Veloc&ity"), seqBox);
+            tr("Veloc&ity"), this);
     connect(velocity, SIGNAL(valueChanged(int)), this,
             SLOT(updateVelocity(int)));
 #ifdef APPBUILD
@@ -314,7 +155,7 @@ SeqWidget::SeqWidget(
 #endif
 
     notelength = new Slider(0, 127, 1, 16, 60, Qt::Horizontal,
-            tr("N&ote Length"), seqBox);
+            tr("N&ote Length"), this);
     connect(notelength, SIGNAL(valueChanged(int)), this,
             SLOT(updateNoteLength(int)));
 #ifdef APPBUILD
@@ -322,7 +163,7 @@ SeqWidget::SeqWidget(
 #endif
 
     transpose = new Slider(-24, 24, 1, 2, 0, Qt::Horizontal,
-            tr("&Transpose"), seqBox);
+            tr("&Transpose"), this);
     connect(transpose, SIGNAL(valueChanged(int)), this,
             SLOT(updateTranspose(int)));
 #ifdef APPBUILD
@@ -366,33 +207,19 @@ SeqWidget::SeqWidget(
     QHBoxLayout *widgetLayout = new QHBoxLayout;
     widgetLayout->addWidget(seqBox, 1);
     widgetLayout->addWidget(hideInOutBoxButton, 0);
-    widgetLayout->addWidget(inOutBox, 0);
-
-#ifdef APPBUILD
-        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
-        midiControl->addMidiLearnMenu("Restore_"+name, parStore->topButton, 7);
-        connect(parStore, SIGNAL(store(int, bool)),
-                 this, SLOT(storeParams(int, bool)));
-        connect(parStore, SIGNAL(restore(int)),
-                 this, SLOT(restoreParams(int)));
-#endif
+    widgetLayout->addWidget(inOutBoxWidget, 0);
 
     muteOutAction->setChecked(mutedAdd);
+#ifdef APPBUILD
+    midiControl->addMidiLearnMenu("Out Channel", channelOut, 9);
+#endif
 
     setLayout(widgetLayout);
     recordMode = false;
-    dataChanged=false;
-    needsGUIUpdate=false;
     updateVelocity(64);
     updateWaveForm(0);
     lastMute = false;
-}
-
-SeqWidget::~SeqWidget()
-{
-#ifdef APPBUILD
-    delete parStore;
-#endif
+    modified = false;
 }
 
 #ifdef APPBUILD
@@ -406,41 +233,11 @@ void SeqWidget::writeData(QXmlStreamWriter& xml)
     QByteArray tempArray;
     int l1;
 
-    xml.writeStartElement(manageBox->name.left(3));
-    xml.writeAttribute("name", manageBox->name.mid(manageBox->name.indexOf(':') + 1));
-    xml.writeAttribute("inOutVisible", QString::number(inOutBox->isVisible()));
+        writeCommonData(xml);
 
         xml.writeStartElement("display");
             xml.writeTextElement("vertical", QString::number(
-                dispVertical));
-        xml.writeEndElement();
-
-        xml.writeStartElement("input");
-            xml.writeTextElement("enableNote", QString::number(
-                midiWorker->enableNoteIn));
-            xml.writeTextElement("enableNoteOff", QString::number(
-                midiWorker->enableNoteOff));
-            xml.writeTextElement("enableVelocity", QString::number(
-                midiWorker->enableVelIn));
-            xml.writeTextElement("restartByKbd", QString::number(
-                midiWorker->restartByKbd));
-            xml.writeTextElement("trigByKbd", QString::number(
-                midiWorker->trigByKbd));
-            xml.writeTextElement("trigLegato", QString::number(
-                midiWorker->trigLegato));
-            xml.writeTextElement("channel", QString::number(
-                midiWorker->chIn));
-        xml.writeEndElement();
-
-        xml.writeStartElement("output");
-            xml.writeTextElement("muted", QString::number(
-                midiWorker->isMuted));
-            xml.writeTextElement("defer", QString::number(
-                midiWorker->deferChanges));
-            xml.writeTextElement("port", QString::number(
-                midiWorker->portOut));
-            xml.writeTextElement("channel", QString::number(
-                midiWorker->channelOut));
+                dispVertIndex));
         xml.writeEndElement();
 
         xml.writeStartElement("seqParams");
@@ -453,7 +250,7 @@ void SeqWidget::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("velocity", QString::number(
                 midiWorker->vel));
             xml.writeTextElement("noteLength", QString::number(
-                midiWorker->notelength));
+                tickLenToSlider(midiWorker->notelength)));
             xml.writeTextElement("transp", QString::number(
                 midiWorker->transp));
         xml.writeEndElement();
@@ -480,10 +277,6 @@ void SeqWidget::writeData(QXmlStreamWriter& xml)
                 getLoopMarker()));
         xml.writeEndElement();
 
-        midiControl->writeData(xml);
-
-        parStore->writeData(xml);
-
     xml.writeEndElement();
 }
 
@@ -496,8 +289,10 @@ void SeqWidget::readData(QXmlStreamReader& xml)
         xml.readNext();
         if (xml.isEndElement())
             break;
-
-        else if (xml.isStartElement() && (xml.name() == "display")) {
+            
+        readCommonData(xml);
+        
+        if (xml.isStartElement() && (xml.name() == "display")) {
             while (!xml.atEnd()) {
                 xml.readNext();
                 if (xml.isEndElement())
@@ -507,54 +302,6 @@ void SeqWidget::readData(QXmlStreamReader& xml)
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "input")) {
-            while (!xml.atEnd()) {
-                xml.readNext();
-                if (xml.isEndElement())
-                    break;
-                if (xml.name() == "enableNote")
-                    enableNoteIn->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "enableNoteOff")
-                    enableNoteOff->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "enableVelocity")
-                    enableVelIn->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "restartByKbd")
-                    enableRestartByKbd->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "trigByKbd")
-                    enableTrigByKbd->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "trigLegato")
-                    enableTrigLegato->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "channel") {
-                    tmp = xml.readElementText().toInt();
-                    chIn->setCurrentIndex(tmp);
-                    updateChIn(tmp);
-                }
-                else skipXmlElement(xml);
-            }
-        }
-
-        else if (xml.isStartElement() && (xml.name() == "output")) {
-            while (!xml.atEnd()) {
-                xml.readNext();
-                if (xml.isEndElement())
-                    break;
-                if (xml.name() == "muted")
-                    muteOutAction->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "defer")
-                    deferChangesAction->setChecked(xml.readElementText().toInt());
-                else if (xml.name() == "channel") {
-                    tmp = xml.readElementText().toInt();
-                    channelOut->setCurrentIndex(tmp);
-                    updateChannelOut(tmp);
-                }
-                else if (xml.name() == "port") {
-                    tmp = xml.readElementText().toInt();
-                    portOut->setCurrentIndex(tmp);
-                    updatePortOut(tmp);
-                }
-                else skipXmlElement(xml);
-            }
-        }
 
         else if (xml.isStartElement() && (xml.name() == "seqParams")) {
             while (!xml.atEnd()) {
@@ -635,78 +382,16 @@ void SeqWidget::readData(QXmlStreamReader& xml)
                 else skipXmlElement(xml);
             }
         }
-        else if (xml.isStartElement() && (xml.name() == "midiControllers")) {
-            midiControl->readData(xml);
-        }
-        else if (xml.isStartElement() && (xml.name() == "globalStores")) {
-            parStore->readData(xml);
-        }
         else skipXmlElement(xml);
     }
+    
+    updateChIn(chIn->currentIndex());
+    updateChannelOut(channelOut->currentIndex());
+    updatePortOut(portOut->currentIndex());
     modified = false;
 }
 #endif
 
-void SeqWidget::setEnableNoteIn(bool on)
-{
-    enableNoteIn->setChecked(on);
-    modified = true;
-}
-
-void SeqWidget::setEnableVelIn(bool on)
-{
-    enableVelIn->setChecked(on);
-    modified = true;
-}
-
-void SeqWidget::setChIn(int value)
-{
-    chIn->setCurrentIndex(value);
-    modified = true;
-}
-
-void SeqWidget::updateChIn(int value)
-{
-    if (midiWorker) midiWorker->chIn = value;
-    modified = true;
-}
-
-void SeqWidget::updateEnableNoteIn(bool on)
-{
-    if (midiWorker) midiWorker->enableNoteIn = on;
-    modified = true;
-}
-
-void SeqWidget::updateEnableNoteOff(bool on)
-{
-    if (midiWorker) midiWorker->enableNoteOff = on;
-    modified = true;
-}
-
-void SeqWidget::updateEnableVelIn(bool on)
-{
-    if (midiWorker) midiWorker->enableVelIn = on;
-    modified = true;
-}
-
-void SeqWidget::updateEnableRestartByKbd(bool on)
-{
-    if (midiWorker) midiWorker->restartByKbd = on;
-    modified = true;
-}
-
-void SeqWidget::updateEnableTrigByKbd(bool on)
-{
-    if (midiWorker) midiWorker->trigByKbd = on;
-    modified = true;
-}
-
-void SeqWidget::updateTrigLegato(bool on)
-{
-    if (midiWorker) midiWorker->trigLegato = on;
-    modified = true;
-}
-
 void SeqWidget::updateNoteLength(int val)
 {
     if (midiWorker) midiWorker->updateNoteLength(sliderToTickLen(val));
@@ -763,7 +448,6 @@ void SeqWidget::updateLoop(int val)
     modified = true;
 }
 
-
 void SeqWidget::updateVelocity(int val)
 {
     if (midiWorker) midiWorker->updateVelocity(val);
@@ -799,53 +483,6 @@ void SeqWidget::mouseEvent(double mouseX, double mouseY, int buttons, int presse
     modified = true;
 }
 
-void SeqWidget::setInOutBoxVisible(bool on)
-{
-    inOutBox->setVisible(on);
-    modified=true;
-}
-
-void SeqWidget::setMuted(bool on)
-{
-    if (!midiWorker) return;
-    midiWorker->setMuted(on);
-    screen->setMuted(midiWorker->isMuted);
-#ifdef APPBUILD
-    parStore->ndc->setMuted(midiWorker->isMuted);
-#endif
-    modified = true;
-}
-
-void SeqWidget::updateDeferChanges(bool on)
-{
-    if (midiWorker) midiWorker->updateDeferChanges(on);
-    modified = true;
-}
-
-void SeqWidget::setPortOut(int value)
-{
-    portOut->setCurrentIndex(value);
-    modified = true;
-}
-
-void SeqWidget::setChannelOut(int value)
-{
-    channelOut->setCurrentIndex(value);
-    modified = true;
-}
-
-void SeqWidget::updatePortOut(int value)
-{
-    if (midiWorker) midiWorker->portOut = value;
-    modified = true;
-}
-
-void SeqWidget::updateChannelOut(int value)
-{
-    if (midiWorker) midiWorker->channelOut = value;
-    modified = true;
-}
-
 void SeqWidget::setDispVert(int mode)
 {
     dispVert[mode]->setChecked(true);
@@ -853,86 +490,23 @@ void SeqWidget::setDispVert(int mode)
 
 void SeqWidget::updateDispVert(int mode)
 {
-    int noct, baseoct;
-
-    switch (mode) {
-        case 0:
-            noct = 4;
-            baseoct = 3;
-        break;
-        case 1:
-            noct = 2;
-            baseoct = 5;
-        break;
-        case 2:
-            noct = 2;
-            baseoct = 4;
-        break;
-        case 3:
-            noct = 2;
-            baseoct = 3;
-        break;
-        default:
-            noct = 4;
-            baseoct = 3;
-    }
-
-    dispVertical = mode;
-    if (midiWorker) midiWorker->nOctaves = noct;
-    if (midiWorker) midiWorker->baseOctave = baseoct;
-    screen->nOctaves = noct;
-    screen->baseOctave = baseoct;
-    screen->update();
+    dispVertIndex = mode;
+    if (midiWorker) midiWorker->updateDispVert(mode);
+    screen->updateDispVert(mode);
     modified = true;
 }
 
-void SeqWidget::storeParams(int ix, bool empty)
-{
 #ifdef APPBUILD
-    // have to do this for moc not caring for APPBUILD flag
-    doStoreParams(ix, empty);
-#else
-    (void)ix;
-    (void)empty;
-#endif
-}
 
-void SeqWidget::restoreParams(int ix)
+void SeqWidget::doStoreParams(int ix)
 {
-#ifdef APPBUILD
-    // have to do this for moc not caring for APPBUILD flag
-    doRestoreParams(ix);
-#else
-    (void)ix;
-#endif
-}
-
-#ifdef APPBUILD
-bool SeqWidget::isModified()
-{
-    return (modified || midiControl->isModified());
-}
-
-void SeqWidget::setModified(bool m)
-{
-    modified = m;
-    midiControl->setModified(m);
-}
-
-void SeqWidget::doStoreParams(int ix, bool empty)
-{
-    parStore->temp.empty = empty;
-    parStore->temp.muteOut = muteOut->isChecked();
-    parStore->temp.chIn = chIn->currentIndex();
-    parStore->temp.channelOut = channelOut->currentIndex();
-    parStore->temp.portOut = portOut->currentIndex();
     parStore->temp.res = resBox->currentIndex();
     parStore->temp.size = sizeBox->currentIndex();
     parStore->temp.loopMode = loopBox->currentIndex();
     parStore->temp.notelen = notelength->value();
     parStore->temp.transp = transpose->value();
     parStore->temp.vel = velocity->value();
-    parStore->temp.dispVertical = dispVertical;
+    parStore->temp.dispVertIndex = dispVertIndex;
     parStore->temp.loopMode = loopBox->currentIndex();
     parStore->temp.wave = getCustomWave().mid(0, midiWorker->maxNPoints);
     parStore->temp.muteMask = midiWorker->muteMask.mid(0, midiWorker->maxNPoints);
@@ -964,15 +538,7 @@ void SeqWidget::doRestoreParams(int ix)
         midiWorker->notelength = sliderToTickLen(parStore->list.at(ix).notelen);
         midiWorker->transp = parStore->list.at(ix).transp;
         midiWorker->vel = parStore->list.at(ix).vel;
-        setDispVert(parStore->list.at(ix).dispVertical);
-
-        //muteOut->setChecked(parStore->list.at(ix).muteOut);
-        chIn->setCurrentIndex(parStore->list.at(ix).chIn);
-        updateChIn(parStore->list.at(ix).chIn);
-        channelOut->setCurrentIndex(parStore->list.at(ix).channelOut);
-        updateChannelOut(parStore->list.at(ix).channelOut);
-        setPortOut(parStore->list.at(ix).portOut);
-        updatePortOut(parStore->list.at(ix).portOut);
+        setDispVert(parStore->list.at(ix).dispVertIndex);
     }
     updateLoop(parStore->list.at(ix).loopMode);
     updateWaveForm(parStore->list.at(ix).waveForm);
@@ -984,7 +550,7 @@ void SeqWidget::doRestoreParams(int ix)
 void SeqWidget::copyParamsFrom(SeqWidget *fromWidget)
 {
     int tmp;
-    setDispVert(fromWidget->dispVertical);
+    setDispVert(fromWidget->dispVertIndex);
     enableNoteIn->setChecked(fromWidget->enableNoteIn->isChecked());
     enableNoteOff->setChecked(fromWidget->enableNoteOff->isChecked());
     enableVelIn->setChecked(fromWidget->enableVelIn->isChecked());
@@ -992,6 +558,14 @@ void SeqWidget::copyParamsFrom(SeqWidget *fromWidget)
     enableTrigByKbd->setChecked(fromWidget->enableTrigByKbd->isChecked());
     enableTrigLegato->setChecked(fromWidget->enableTrigLegato->isChecked());
 
+    for (int l1 = 0; l1 < 1; l1++) {
+        tmp = fromWidget->indexIn[l1]->value();
+        indexIn[l1]->setValue(tmp);
+    }
+    for (int l1 = 0; l1 < 1; l1++) {
+        tmp = fromWidget->rangeIn[l1]->value();
+        rangeIn[l1]->setValue(tmp);
+    }
     tmp = fromWidget->chIn->currentIndex();
     chIn->setCurrentIndex(tmp);
     updateChIn(tmp);
@@ -1119,6 +693,11 @@ void SeqWidget::handleController(int ccnumber, int channel, int value)
                         sval = min + ((double)value * (max - min) / 127);
                         midiWorker->updateTranspose(sval - 24);
                 break;
+                
+                case 9:
+                        sval = min + ((double)value * (max - min) / 127);
+                        if (sval < 16) midiWorker->channelOut = sval;
+                break;
 
                 default:
                 break;
@@ -1134,7 +713,6 @@ void SeqWidget::updateDisplay()
 
     parStore->updateDisplay(getCurrentIndex(), midiWorker->reverse);
 
-
     if (dataChanged || midiWorker->dataChanged) {
         dataChanged=false;
         midiWorker->dataChanged=false;
@@ -1152,7 +730,9 @@ void SeqWidget::updateDisplay()
     transpose->setValue(midiWorker->transp);
     notelength->setValue(tickLenToSlider(midiWorker->notelength));
     velocity->setValue(midiWorker->vel);
-    muteOutAction->setChecked(midiWorker->isMuted);
+    muteOut->setChecked(midiWorker->isMuted);
+    screen->newGrooveValues(midiWorker->newGrooveTick, midiWorker->grooveVelocity,
+                midiWorker->grooveLength);
     screen->setMuted(midiWorker->isMuted);
     parStore->ndc->setMuted(midiWorker->isMuted);
     recordAction->setChecked(midiWorker->recordMode);
@@ -1161,24 +741,9 @@ void SeqWidget::updateDisplay()
     sizeBox->setCurrentIndex(sizeBoxIndex);
     updateSize(sizeBoxIndex);
     loopBox->setCurrentIndex(midiWorker->curLoopMode);
-
+    channelOut->setCurrentIndex(midiWorker->channelOut);
     needsGUIUpdate = false;
     midiWorker->needsGUIUpdate = false;
 }
-void SeqWidget::skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
 
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
 #endif
