@@ -2,9 +2,8 @@
  * @file seqwidget.h
  * @brief Member definitions for the SeqWidget GUI class.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -38,14 +37,8 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-#ifdef APPBUILD
-#include "globstore.h"
-#include "midicontrol.h"
-#include "managebox.h"
-#include "parstore.h"
-#endif
-
 #include "midiseq.h"
+#include "inoutbox.h"
 #include "slider.h"
 #include "seqscreen.h"
 #include "cursor.h"
@@ -61,19 +54,13 @@
  * and interacts with it.
  *
 */
-class SeqWidget : public QWidget
+class SeqWidget : public InOutBox
 {
     Q_OBJECT
 
     MidiSeq *midiWorker;
-#ifdef APPBUILD
-    GlobStore *globStore;
-#endif
-    bool modified;      /**< Is set to True if unsaved parameter modifications exist */
     bool lastMute;      /**< Contains the mute state of the last waveForm point modified by mouse click*/
     bool recordMode;    /**< Is set to True if incoming notes are to be step-recorded*/
-    bool dataChanged;
-    bool needsGUIUpdate;
 
 /* PUBLIC MEMBERS */
   public:
@@ -83,72 +70,40 @@ class SeqWidget : public QWidget
  * instance.
  *
  * @param p_midiWorker Associated MidiSeq Object
+ * @param p_globStore The Application-wide globStore widget
  * @param portCount Number of available MIDI output ports
  * @param compactStyle If set to True, Widget will use reduced spacing and small fonts
  * @param mutedAdd If set to True, the module will be added in muted state
- * @param parent The parent widget of this module, i.e. MainWindow
+ * @param inOutVisible Add the module with visible InOutBox or not
+ * @param name The name of the module preceded by its type (Arp: , etc...)
  */
     SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
-            const QString& name = "", QWidget* parent=0);
+            const QString& name = "");
 
-    ParStore *parStore;
-    MidiControl *midiControl;
-    ManageBox *manageBox;
 #else
     SeqWidget(
             bool compactStyle,
-            bool mutedAdd = false, bool inOutVisible = true,
-            QWidget* parent=0);
+            bool mutedAdd = false, bool inOutVisible = true);
 #endif
-    ~SeqWidget();
 
     QVector<Sample> data;
     SeqScreen *screen;
     Cursor *cursor;
 
-    QComboBox *chIn;
-    QComboBox *channelOut, *portOut;
     QComboBox *resBox, *sizeBox, *freqBox;
     QComboBox *loopBox;
-    QWidget *inOutBox;
-    QAction *muteOutAction;
-    QAction *deferChangesAction;
-    QToolButton *muteOut;
-    QCheckBox *enableNoteIn;
-    QCheckBox *enableNoteOff;
-    QCheckBox *enableVelIn;
-    QCheckBox *enableRestartByKbd;
-    QCheckBox *enableTrigByKbd;
-    QCheckBox *enableTrigLegato;
     QCheckBox *dispVert[4];
     Slider *velocity, *transpose, *notelength;
     QAction *recordAction;
-    QAction* hideInOutBoxAction;
-    int dispVertical;
+    QSignalMapper *dispSignalMapper;
+    int dispVertIndex;
     int resBoxIndex;
     int sizeBoxIndex;
 
-    void setChIn(int value);
-    void setEnableNoteIn(bool on);
-    void setEnableVelIn(bool on);
     QVector<Sample> getCustomWave();
 
-/*!
-* @brief Setter for the SeqWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
-*
-*/
-    void setChannelOut(int value);
-/*!
-* @brief Setter for the SeqWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void setPortOut(int value);
 
 #ifdef APPBUILD
 /*!
@@ -179,33 +134,12 @@ class SeqWidget : public QWidget
 * @param fromWidget pointer to the SeqWidget parameters are to be taken from
 */
     void copyParamsFrom(SeqWidget *fromWidget);
-/*!
-* @brief Accessor for SeqWidget::modified.
-* @return True if unsaved parameter modifications exist
-*
-*/
-    bool isModified();
-/*!
-* @brief sets SeqWidget::modified.
-* @param m Set to True if unsaved parameter modifications appear
-*
-*/
-    void setModified(bool);
-    void skipXmlElement(QXmlStreamReader& xml);
-/*!
-* @brief stores some module parameters in a parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
-    void doStoreParams(int ix, bool empty);
-/*!
-* @brief restores some module parameters from the parameter
-* list object
-*
-* @param Position index in the parameter list
-*/
+
+    void doStoreParams(int ix);
     void doRestoreParams(int ix);
+    void updateDisplay();
+    void handleController(int ccnumber, int channel, int value);
+
 #endif
 
 /* SIGNALS */
@@ -269,17 +203,9 @@ class SeqWidget : public QWidget
     void updateNoteLength(int val);
     void updateTranspose(int val);
 
-    void updateChIn(int value);
-    void updateEnableNoteIn(bool on);
-    void updateEnableVelIn(bool on);
-    void updateEnableNoteOff(bool on);
-    void updateEnableRestartByKbd(bool on);
-    void updateEnableTrigByKbd(bool on);
-    void updateTrigLegato(bool on);
     void setRecord(bool on);
     void setDispVert(int mode);
     void updateDispVert(int mode);
-    void setInOutBoxVisible(bool on);
 
 /*!
 * @brief Slot for the SeqScreen::mouseEvent signal.
@@ -300,60 +226,6 @@ class SeqWidget : public QWidget
 *
 */
     void mouseEvent(double, double, int, int pressed);
-/*!
-* @brief Slot for the SeqWidget::channelOut spinbox setting the output
-* channel of this module.
-* @param value Number of the output channel to send data to
-*
-*/
-    void updateChannelOut(int value);
-/*!
-* @brief Slot for the SeqWidget::portOut spinbox setting the output
-* port of this module.
-* @param value Number of the output port to send data to
-*
-*/
-    void updatePortOut(int value);
-/*!
-* @brief Slot for the SeqWidget::muteOut action.
-* Suppresses output of Seq data.
-*
-* It calls
-* MidiSeq::setMuted and SeqScreen::setMuted
-* @param on Set to True for muting this module
-*
-*/
-    void setMuted(bool on);
-/*!
-* @brief Slot for the SeqWidget::deferChanges action.
-*
-* Sets a flag in the midi worker causing parameter changes to become
-* active/inactive only at pattern end.
-*
-* @param on Set to True for deferring parameter changes to pattern end
-*/
-    void updateDeferChanges(bool on);
-
-    void storeParams(int ix, bool empty = false);
-    void restoreParams(int ix);
-
-#ifdef APPBUILD
-    void handleController(int ccnumber, int channel, int value);
-/*!
- * @brief Updates the SeqScreen and other GUI elements with data from
- * the MidiSeq instance.
- *
- * It is called by Engine::updateDisplay(), which itself is
- * connected to the MTimer::timeout event. It runs in the MTimer thread.
- * It reads the waveform data and other settings from the MidiSeq instance
- * and sets GUI cursor, wave display and other elements accordingly. This
- * way, no memory allocations are done within the jack run thread, for
- * instance by MIDI controllers, since the Qt widgets are not called directly.
- * This function also checks whether parameter chages from ParStore are
- * pending and causes them to get transferred if so.
- */
-    void updateDisplay();
-#endif
 
     int getCurrentIndex() { return midiWorker->getCurrentIndex(); }
     int getLoopMarker() { return midiWorker->loopMarker; }
