@@ -2,9 +2,8 @@
  * @file seqwidget_lv2.cpp
  * @brief Implements the the LV2 GUI for the QMidiArp Seq plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ SeqWidgetLV2::SeqWidgetLV2 (
         LV2UI_Controller ct,
         LV2UI_Write_Function write_function,
         const LV2_Feature *const *host_features)
-        : SeqWidget(true, true, true, 0)
+        : SeqWidget(true, true, true)
 {
     m_controller = ct;
     writeFunction = write_function;
@@ -75,9 +74,9 @@ SeqWidgetLV2::SeqWidgetLV2 (
     connect(transportBox, SIGNAL(toggled(bool)), tempoSpin, SLOT(setDisabled(bool)));
     transportBox->setChecked(true);
 
-    inOutBox->layout()->addWidget(transportBoxLabel);
-    inOutBox->layout()->addWidget(transportBox);
-    inOutBox->layout()->addWidget(tempoSpin);
+    inOutBoxWidget->layout()->addWidget(transportBoxLabel);
+    inOutBoxWidget->layout()->addWidget(transportBox);
+    inOutBoxWidget->layout()->addWidget(tempoSpin);
 
     connect(velocity,           SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(notelength,         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
@@ -87,7 +86,12 @@ SeqWidgetLV2::SeqWidgetLV2 (
     connect(loopBox,            SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(channelOut,         SIGNAL(activated(int)), this, SLOT(mapParam(int)));
     connect(chIn,               SIGNAL(activated(int)), this, SLOT(mapParam(int)));
+    connect(indexIn[0],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(indexIn[1],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(rangeIn[0],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(rangeIn[1],         SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
     connect(tempoSpin,          SIGNAL(valueChanged(int)), this, SLOT(mapParam(int)));
+    connect(dispSignalMapper,   SIGNAL(mapped(int)),   this, SLOT(mapParam(int)));
 
     connect(muteOutAction,      SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
     connect(enableNoteIn,       SIGNAL(toggled(bool)), this, SLOT(mapBool(bool)));
@@ -129,14 +133,11 @@ void SeqWidgetLV2::port_event ( uint32_t port_index,
     if (!data.count()) sendUIisUp(true);
 
     if (format == uris->atom_eventTransfer
-      && atom->type == uris->atom_Blank) {
+      && atom->type == uris->atom_Object) {
         receiveWave(atom);
     }
     else if (format == 0 && buffer_size == sizeof(float)) {
 
-        res = resBox->currentText().toInt();
-        size = sizeBox->currentText().toInt();
-
         float fValue = *(float *) buffer;
 
         switch (port_index) {
@@ -161,6 +162,18 @@ void SeqWidgetLV2::port_event ( uint32_t port_index,
             case CH_IN:
                     chIn->setCurrentIndex(fValue);
             break;
+            case INDEX_IN1:
+                    indexIn[0]->setValue(fValue);
+            break;
+            case INDEX_IN2:
+                    indexIn[1]->setValue(fValue);
+            break;
+            case RANGE_IN1:
+                    rangeIn[0]->setValue(fValue);
+            break;
+            case RANGE_IN2:
+                    rangeIn[1]->setValue(fValue);
+            break;
             case CURSOR_POS:
                     cursor->updateNumbers(res, size);
                     cursor->updatePosition(fValue);
@@ -178,6 +191,9 @@ void SeqWidgetLV2::port_event ( uint32_t port_index,
                     screen->setMuted(fValue);
                     screen->update();
             break;
+            case DISPLAY_ZOOM:
+                    setDispVert((int)fValue);
+            break;
             case MOUSEX:
             case MOUSEY:
             case MOUSEBUTTON:
@@ -238,7 +254,7 @@ void SeqWidgetLV2::sendUIisUp(bool on)
 
     if (on) state = uris->ui_up; else state=uris->ui_down;
 
-    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_blank(&forge, &frame, 1, state);
+    LV2_Atom* msg = (LV2_Atom*)lv2_atom_forge_object(&forge, &frame, 1, state);
 
     /* close-off frame */
     lv2_atom_forge_pop(&forge, &frame);
@@ -248,7 +264,8 @@ void SeqWidgetLV2::sendUIisUp(bool on)
 void SeqWidgetLV2::receiveWave(LV2_Atom* atom)
 {
     QMidiArpURIs* const uris = &m_uris;
-    if (atom->type != uris->atom_Blank) return;
+    if ( (atom->type != uris->atom_Blank) 
+            && (atom->type != uris->atom_Object)) return;
 
     /* cast the buffer to Atom Object */
     LV2_Atom_Object* obj = (LV2_Atom_Object*)atom;
@@ -266,6 +283,8 @@ void SeqWidgetLV2::receiveWave(LV2_Atom* atom)
     const size_t n_elem = (a0->size - sizeof(LV2_Atom_Vector_Body)) / voi->atom.size;
     /* typecast, dereference pointer to vector */
     const int *recdata = (int*) LV2_ATOM_BODY(&voi->atom);
+    res = resBox->currentText().toInt();
+    size = sizeBox->currentText().toInt();
     for (uint l1 = 0; l1 < n_elem; l1++) {
         receiveWavePoint(l1, recdata[l1]);
     }
@@ -291,7 +310,10 @@ void SeqWidgetLV2::receiveWavePoint(int index, int value)
 void SeqWidgetLV2::mapBool(bool on)
 {
     float value = (float)on;
-    if (muteOutAction == sender())              updateParam(MUTE, value);
+    if (muteOutAction == sender()) {
+        updateParam(MUTE, value);
+        screen->setMuted(value);
+    }
     else if (enableNoteIn == sender())          updateParam(ENABLE_NOTEIN, value);
     else if (enableVelIn == sender())           updateParam(ENABLE_VELIN, value);
     else if (enableNoteOff == sender())         updateParam(ENABLE_NOTEOFF, value);
@@ -321,8 +343,13 @@ void SeqWidgetLV2::mapParam(int value)
     else if (transpose == sender())     updateParam(TRANSPOSE, value);
     else if (channelOut == sender())    updateParam(CH_OUT, value);
     else if (chIn == sender())          updateParam(CH_IN, value);
+    else if (indexIn[0] == sender())    updateParam(INDEX_IN1, value);
+    else if (indexIn[1] == sender())    updateParam(INDEX_IN2, value);
+    else if (rangeIn[0] == sender())    updateParam(RANGE_IN1, value);
+    else if (rangeIn[1] == sender())    updateParam(RANGE_IN2, value);
     else if (loopBox == sender())       updateParam(LOOPMODE, value);
     else if (tempoSpin == sender())     updateParam(TEMPO, value);
+    else if (dispSignalMapper == sender())     updateParam(DISPLAY_ZOOM, value);
 }
 
 void SeqWidgetLV2::updateParam(int index, float fValue) const
