@@ -2,9 +2,8 @@
  * @file seqwidget_lv2.h
  * @brief Headers for the LV2 GUI for the QMidiArp Seq plugin.
  *
- * @section LICENSE
  *
- *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -66,14 +65,19 @@ class SeqWidgetLV2 : public SeqWidget
             ENABLE_RESTARTBYKBD = 20,
             ENABLE_TRIGBYKBD = 21,
             ENABLE_TRIGLEGATO = 22,
-            RECORD = 23,
-            DEFER = 24,
-            CURR_RECSTEP = 25, //output
-            TRANSPORT_MODE = 26,
-            TEMPO = 27,
-            HOST_TEMPO = 28,
-            HOST_POSITION = 29,
-            HOST_SPEED = 30
+            INDEX_IN1 = 23,
+            INDEX_IN2 = 24,
+            RANGE_IN1 = 25,
+            RANGE_IN2 = 26,
+            RECORD = 27,
+            DEFER = 28,
+            CURR_RECSTEP = 29, //output
+            TRANSPORT_MODE = 30,
+            TEMPO = 31,
+            HOST_TEMPO = 32,
+            HOST_POSITION = 33,
+            HOST_SPEED = 34,
+            DISPLAY_ZOOM = 35
     };
 
     SeqWidgetLV2(
